@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class ApplicationLoadbalancer(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.applicationLoadbalancer.ApplicationLoadbalancer",
 ):
@@ -30,7 +30,7 @@ class ApplicationLoadbalancer(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         datacenter_id: builtins.str,
@@ -40,14 +40,14 @@ class ApplicationLoadbalancer(
         id: typing.Optional[builtins.str] = None,
         ips: typing.Optional[typing.Sequence[builtins.str]] = None,
         lb_private_ips: typing.Optional[typing.Sequence[builtins.str]] = None,
-        timeouts: typing.Optional[typing.Union["ApplicationLoadbalancerTimeouts", typing.Dict[str, typing.Any]]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        timeouts: typing.Optional[typing.Union["ApplicationLoadbalancerTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/ionoscloud/r/application_loadbalancer ionoscloud_application_loadbalancer} Resource.
 
@@ -70,7 +70,7 @@ class ApplicationLoadbalancer(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ApplicationLoadbalancer.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__dd8302fa48da657028bdebf3db919149e51949dbd1daa4ebd013f428c35c16a3)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = ApplicationLoadbalancerConfig(
@@ -183,8 +183,8 @@ class ApplicationLoadbalancer(
     @jsii.member(jsii_name="timeoutsInput")
     def timeouts_input(
         self,
-    ) -> typing.Optional[typing.Union["ApplicationLoadbalancerTimeouts", cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union["ApplicationLoadbalancerTimeouts", cdktf.IResolvable]], jsii.get(self, "timeoutsInput"))
+    ) -> typing.Optional[typing.Union["ApplicationLoadbalancerTimeouts", _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union["ApplicationLoadbalancerTimeouts", _cdktf_9a9027ec.IResolvable]], jsii.get(self, "timeoutsInput"))
 
     @builtins.property
     @jsii.member(jsii_name="datacenterId")
@@ -194,7 +194,7 @@ class ApplicationLoadbalancer(
     @datacenter_id.setter
     def datacenter_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ApplicationLoadbalancer, "datacenter_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__00542b95ea4d12d367e79e415032ad3609ee6c38a77c6784712d57f85acb5e4e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "datacenterId", value)
 
@@ -206,7 +206,7 @@ class ApplicationLoadbalancer(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ApplicationLoadbalancer, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__6b3153775a60431c45361e3d42b8e35612c6aa57419309549bce0f47d141aba5)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -218,7 +218,7 @@ class ApplicationLoadbalancer(
     @ips.setter
     def ips(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ApplicationLoadbalancer, "ips").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__87c27a5b50cfea831406c7ea46b240927a594a6f02ece1495e6f432f3676cd9c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ips", value)
 
@@ -230,7 +230,7 @@ class ApplicationLoadbalancer(
     @lb_private_ips.setter
     def lb_private_ips(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ApplicationLoadbalancer, "lb_private_ips").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__813999821899367ebcde8c7c32f8948ec533ffb9ce4a649f46022524148213e7)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "lbPrivateIps", value)
 
@@ -242,7 +242,7 @@ class ApplicationLoadbalancer(
     @listener_lan.setter
     def listener_lan(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ApplicationLoadbalancer, "listener_lan").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__3baf0d043e32c50df088e6334f8650add7f70bc79d7cdadb5b0c5c7d5ae83b12)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "listenerLan", value)
 
@@ -254,7 +254,7 @@ class ApplicationLoadbalancer(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ApplicationLoadbalancer, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__dda2999ed1b173d0f563e0d77405f4de20c2b164c34e8f5aefe37ac337ec2c89)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -266,14 +266,14 @@ class ApplicationLoadbalancer(
     @target_lan.setter
     def target_lan(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ApplicationLoadbalancer, "target_lan").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__885936d6034b02e7ec8a95ed68b9f8d0237534542f5a091a4615d6c8acb4037e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "targetLan", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-ionoscloud.applicationLoadbalancer.ApplicationLoadbalancerConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -292,17 +292,17 @@ class ApplicationLoadbalancer(
         "timeouts": "timeouts",
     },
 )
-class ApplicationLoadbalancerConfig(cdktf.TerraformMetaArguments):
+class ApplicationLoadbalancerConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         datacenter_id: builtins.str,
         listener_lan: jsii.Number,
         name: builtins.str,
@@ -310,7 +310,7 @@ class ApplicationLoadbalancerConfig(cdktf.TerraformMetaArguments):
         id: typing.Optional[builtins.str] = None,
         ips: typing.Optional[typing.Sequence[builtins.str]] = None,
         lb_private_ips: typing.Optional[typing.Sequence[builtins.str]] = None,
-        timeouts: typing.Optional[typing.Union["ApplicationLoadbalancerTimeouts", typing.Dict[str, typing.Any]]] = None,
+        timeouts: typing.Optional[typing.Union["ApplicationLoadbalancerTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param connection: 
@@ -330,11 +330,11 @@ class ApplicationLoadbalancerConfig(cdktf.TerraformMetaArguments):
         :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/r/application_loadbalancer#timeouts ApplicationLoadbalancer#timeouts}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(timeouts, dict):
             timeouts = ApplicationLoadbalancerTimeouts(**timeouts)
         if __debug__:
-            type_hints = typing.get_type_hints(ApplicationLoadbalancerConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__747d139590f641136669306bbf647f79a5cd928e446ec8c7d4fbb9f7d74d190a)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -350,7 +350,7 @@ class ApplicationLoadbalancerConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument ips", value=ips, expected_type=type_hints["ips"])
             check_type(argname="argument lb_private_ips", value=lb_private_ips, expected_type=type_hints["lb_private_ips"])
             check_type(argname="argument timeouts", value=timeouts, expected_type=type_hints["timeouts"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "datacenter_id": datacenter_id,
             "listener_lan": listener_lan,
             "name": name,
@@ -382,12 +382,12 @@ class ApplicationLoadbalancerConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -398,46 +398,48 @@ class ApplicationLoadbalancerConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def datacenter_id(self) -> builtins.str:
@@ -555,12 +557,12 @@ class ApplicationLoadbalancerTimeouts:
         :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/r/application_loadbalancer#update ApplicationLoadbalancer#update}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ApplicationLoadbalancerTimeouts.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__7feb05f3a38451713f927ef43e7fd1e22dbb43785ba641c4f33f4634a98eaf24)
             check_type(argname="argument create", value=create, expected_type=type_hints["create"])
             check_type(argname="argument default", value=default, expected_type=type_hints["default"])
             check_type(argname="argument delete", value=delete, expected_type=type_hints["delete"])
             check_type(argname="argument update", value=update, expected_type=type_hints["update"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if create is not None:
             self._values["create"] = create
         if default is not None:
@@ -607,13 +609,13 @@ class ApplicationLoadbalancerTimeouts:
 
 
 class ApplicationLoadbalancerTimeoutsOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.applicationLoadbalancer.ApplicationLoadbalancerTimeoutsOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -621,7 +623,7 @@ class ApplicationLoadbalancerTimeoutsOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ApplicationLoadbalancerTimeoutsOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__7e9465c5eaf457723210db196e4f9c123beeeb1afa5ce6bfa541a0c8ca1c916d)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -670,7 +672,7 @@ class ApplicationLoadbalancerTimeoutsOutputReference(
     @create.setter
     def create(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ApplicationLoadbalancerTimeoutsOutputReference, "create").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__136bf6c35471b72fc066e919c248305515c9200c366f4dfbe3e8bb31c2e43184)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "create", value)
 
@@ -682,7 +684,7 @@ class ApplicationLoadbalancerTimeoutsOutputReference(
     @default.setter
     def default(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ApplicationLoadbalancerTimeoutsOutputReference, "default").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5e28a2ebe456d7ad00e2f2cbc1fe020bccd13d82d9c5345106cd2ee7cbfabead)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "default", value)
 
@@ -694,7 +696,7 @@ class ApplicationLoadbalancerTimeoutsOutputReference(
     @delete.setter
     def delete(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ApplicationLoadbalancerTimeoutsOutputReference, "delete").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__f55a250058999de18842a0c78a806228bbeb3636fbd7a4a7d256cb1e3235d5f7)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "delete", value)
 
@@ -706,7 +708,7 @@ class ApplicationLoadbalancerTimeoutsOutputReference(
     @update.setter
     def update(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ApplicationLoadbalancerTimeoutsOutputReference, "update").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__9f65c0636bd7c8011f7505b6da2befff448c7796d327d520e86bf35b16cb0a1f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "update", value)
 
@@ -714,16 +716,16 @@ class ApplicationLoadbalancerTimeoutsOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[ApplicationLoadbalancerTimeouts, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[ApplicationLoadbalancerTimeouts, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[ApplicationLoadbalancerTimeouts, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[ApplicationLoadbalancerTimeouts, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[ApplicationLoadbalancerTimeouts, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[ApplicationLoadbalancerTimeouts, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ApplicationLoadbalancerTimeoutsOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__c062050f70630f65af07028a4a1732c626b2e5386c014f57f9863b8e49790a22)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -736,3 +738,136 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__dd8302fa48da657028bdebf3db919149e51949dbd1daa4ebd013f428c35c16a3(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    datacenter_id: builtins.str,
+    listener_lan: jsii.Number,
+    name: builtins.str,
+    target_lan: jsii.Number,
+    id: typing.Optional[builtins.str] = None,
+    ips: typing.Optional[typing.Sequence[builtins.str]] = None,
+    lb_private_ips: typing.Optional[typing.Sequence[builtins.str]] = None,
+    timeouts: typing.Optional[typing.Union[ApplicationLoadbalancerTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__00542b95ea4d12d367e79e415032ad3609ee6c38a77c6784712d57f85acb5e4e(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6b3153775a60431c45361e3d42b8e35612c6aa57419309549bce0f47d141aba5(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__87c27a5b50cfea831406c7ea46b240927a594a6f02ece1495e6f432f3676cd9c(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__813999821899367ebcde8c7c32f8948ec533ffb9ce4a649f46022524148213e7(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3baf0d043e32c50df088e6334f8650add7f70bc79d7cdadb5b0c5c7d5ae83b12(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dda2999ed1b173d0f563e0d77405f4de20c2b164c34e8f5aefe37ac337ec2c89(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__885936d6034b02e7ec8a95ed68b9f8d0237534542f5a091a4615d6c8acb4037e(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__747d139590f641136669306bbf647f79a5cd928e446ec8c7d4fbb9f7d74d190a(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    datacenter_id: builtins.str,
+    listener_lan: jsii.Number,
+    name: builtins.str,
+    target_lan: jsii.Number,
+    id: typing.Optional[builtins.str] = None,
+    ips: typing.Optional[typing.Sequence[builtins.str]] = None,
+    lb_private_ips: typing.Optional[typing.Sequence[builtins.str]] = None,
+    timeouts: typing.Optional[typing.Union[ApplicationLoadbalancerTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7feb05f3a38451713f927ef43e7fd1e22dbb43785ba641c4f33f4634a98eaf24(
+    *,
+    create: typing.Optional[builtins.str] = None,
+    default: typing.Optional[builtins.str] = None,
+    delete: typing.Optional[builtins.str] = None,
+    update: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7e9465c5eaf457723210db196e4f9c123beeeb1afa5ce6bfa541a0c8ca1c916d(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__136bf6c35471b72fc066e919c248305515c9200c366f4dfbe3e8bb31c2e43184(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5e28a2ebe456d7ad00e2f2cbc1fe020bccd13d82d9c5345106cd2ee7cbfabead(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f55a250058999de18842a0c78a806228bbeb3636fbd7a4a7d256cb1e3235d5f7(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9f65c0636bd7c8011f7505b6da2befff448c7796d327d520e86bf35b16cb0a1f(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c062050f70630f65af07028a4a1732c626b2e5386c014f57f9863b8e49790a22(
+    value: typing.Optional[typing.Union[ApplicationLoadbalancerTimeouts, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
