@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class DataIonoscloudK8SNodePoolNodes(
-    cdktf.TerraformDataSource,
+    _cdktf_9a9027ec.TerraformDataSource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.dataIonoscloudK8SNodePoolNodes.DataIonoscloudK8SNodePoolNodes",
 ):
@@ -30,20 +30,20 @@ class DataIonoscloudK8SNodePoolNodes(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         k8_s_cluster_id: builtins.str,
         node_pool_id: builtins.str,
         id: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["DataIonoscloudK8SNodePoolNodesTimeouts", typing.Dict[str, typing.Any]]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        timeouts: typing.Optional[typing.Union["DataIonoscloudK8SNodePoolNodesTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/ionoscloud/d/k8s_node_pool_nodes ionoscloud_k8s_node_pool_nodes} Data Source.
 
@@ -62,7 +62,7 @@ class DataIonoscloudK8SNodePoolNodes(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudK8SNodePoolNodes.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__776c7fb2a367ef55914f78551a8aa3f4fcc5187f063e0f95520e3e09fc6ccc6b)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = DataIonoscloudK8SNodePoolNodesConfig(
@@ -148,8 +148,8 @@ class DataIonoscloudK8SNodePoolNodes(
     @jsii.member(jsii_name="timeoutsInput")
     def timeouts_input(
         self,
-    ) -> typing.Optional[typing.Union["DataIonoscloudK8SNodePoolNodesTimeouts", cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union["DataIonoscloudK8SNodePoolNodesTimeouts", cdktf.IResolvable]], jsii.get(self, "timeoutsInput"))
+    ) -> typing.Optional[typing.Union["DataIonoscloudK8SNodePoolNodesTimeouts", _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union["DataIonoscloudK8SNodePoolNodesTimeouts", _cdktf_9a9027ec.IResolvable]], jsii.get(self, "timeoutsInput"))
 
     @builtins.property
     @jsii.member(jsii_name="id")
@@ -159,7 +159,7 @@ class DataIonoscloudK8SNodePoolNodes(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudK8SNodePoolNodes, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__87fe3f45e04c907e18f1f428ee81b563c8614f86a4aef73626be4ea3da10cd37)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -171,7 +171,7 @@ class DataIonoscloudK8SNodePoolNodes(
     @k8_s_cluster_id.setter
     def k8_s_cluster_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudK8SNodePoolNodes, "k8_s_cluster_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__193d032f70210e225259b1ac04a2a0447f96489f1234548b0c5ecf5587dee618)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "k8SClusterId", value)
 
@@ -183,14 +183,14 @@ class DataIonoscloudK8SNodePoolNodes(
     @node_pool_id.setter
     def node_pool_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudK8SNodePoolNodes, "node_pool_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__0851cf38312654281e52df696575e28943cdb792c019503fda7718f41c84a596)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "nodePoolId", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-ionoscloud.dataIonoscloudK8SNodePoolNodes.DataIonoscloudK8SNodePoolNodesConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -205,21 +205,21 @@ class DataIonoscloudK8SNodePoolNodes(
         "timeouts": "timeouts",
     },
 )
-class DataIonoscloudK8SNodePoolNodesConfig(cdktf.TerraformMetaArguments):
+class DataIonoscloudK8SNodePoolNodesConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         k8_s_cluster_id: builtins.str,
         node_pool_id: builtins.str,
         id: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["DataIonoscloudK8SNodePoolNodesTimeouts", typing.Dict[str, typing.Any]]] = None,
+        timeouts: typing.Optional[typing.Union["DataIonoscloudK8SNodePoolNodesTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param connection: 
@@ -235,11 +235,11 @@ class DataIonoscloudK8SNodePoolNodesConfig(cdktf.TerraformMetaArguments):
         :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/d/k8s_node_pool_nodes#timeouts DataIonoscloudK8SNodePoolNodes#timeouts}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(timeouts, dict):
             timeouts = DataIonoscloudK8SNodePoolNodesTimeouts(**timeouts)
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudK8SNodePoolNodesConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__5812b1f013e8d18336abe24aaaab10d6012a5de6e64c844db45dbf92ef2f5a66)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -251,7 +251,7 @@ class DataIonoscloudK8SNodePoolNodesConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument node_pool_id", value=node_pool_id, expected_type=type_hints["node_pool_id"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument timeouts", value=timeouts, expected_type=type_hints["timeouts"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "k8_s_cluster_id": k8_s_cluster_id,
             "node_pool_id": node_pool_id,
         }
@@ -277,12 +277,12 @@ class DataIonoscloudK8SNodePoolNodesConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -293,46 +293,48 @@ class DataIonoscloudK8SNodePoolNodesConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def k8_s_cluster_id(self) -> builtins.str:
@@ -392,7 +394,7 @@ class DataIonoscloudK8SNodePoolNodesConfig(cdktf.TerraformMetaArguments):
 )
 class DataIonoscloudK8SNodePoolNodesNodes:
     def __init__(self) -> None:
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -407,13 +409,13 @@ class DataIonoscloudK8SNodePoolNodesNodes:
 
 
 class DataIonoscloudK8SNodePoolNodesNodesList(
-    cdktf.ComplexList,
+    _cdktf_9a9027ec.ComplexList,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.dataIonoscloudK8SNodePoolNodes.DataIonoscloudK8SNodePoolNodesNodesList",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         wraps_set: builtins.bool,
     ) -> None:
@@ -423,7 +425,7 @@ class DataIonoscloudK8SNodePoolNodesNodesList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudK8SNodePoolNodesNodesList.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__92f02f1b009594f67fe22ea54257746de3c2827fd6744bb9b94fb685e4735055)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -438,7 +440,7 @@ class DataIonoscloudK8SNodePoolNodesNodesList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudK8SNodePoolNodesNodesList.get)
+            type_hints = typing.get_type_hints(_typecheckingstub__29dee6102d919c589b4939bb772770032986345e8eee0768dc2d18bea10d68c0)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("DataIonoscloudK8SNodePoolNodesNodesOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -451,20 +453,20 @@ class DataIonoscloudK8SNodePoolNodesNodesList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudK8SNodePoolNodesNodesList, "_terraform_attribute").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__bd2db0f660ff71e410d62745ceecbb0dc183d897bea941629f63d1dee7baed94)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
     @builtins.property
     @jsii.member(jsii_name="terraformResource")
-    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
+    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
         '''The parent resource.'''
-        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))
+        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))
 
     @_terraform_resource.setter
-    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
+    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudK8SNodePoolNodesNodesList, "_terraform_resource").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5241675fe38e6b71116016db19579d715d0d133e402ee0aa06589a4781d635d1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -477,19 +479,19 @@ class DataIonoscloudK8SNodePoolNodesNodesList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudK8SNodePoolNodesNodesList, "_wraps_set").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__bab34e311c38b93979f01b12db49429c26e26fd5511187704df2774a7ef662d9)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
 
 class DataIonoscloudK8SNodePoolNodesNodesOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.dataIonoscloudK8SNodePoolNodes.DataIonoscloudK8SNodePoolNodesNodesOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         complex_object_index: jsii.Number,
         complex_object_is_from_set: builtins.bool,
@@ -501,7 +503,7 @@ class DataIonoscloudK8SNodePoolNodesNodesOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudK8SNodePoolNodesNodesOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__8ae17a756bc12305600f80632259d3d722494657cba21db55a0548e98b0311e1)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -544,7 +546,7 @@ class DataIonoscloudK8SNodePoolNodesNodesOutputReference(
         value: typing.Optional[DataIonoscloudK8SNodePoolNodesNodes],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudK8SNodePoolNodesNodesOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__08ccf6bd65b47601f683bf7ffcbd20cb4b7956b228f98a763d905458e1984843)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -575,12 +577,12 @@ class DataIonoscloudK8SNodePoolNodesTimeouts:
         :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/d/k8s_node_pool_nodes#update DataIonoscloudK8SNodePoolNodes#update}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudK8SNodePoolNodesTimeouts.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__e4a891c7c11ea8ca4d03ada3cdfd75d0ba6bec9741f50a7a104e2c1eba85950f)
             check_type(argname="argument create", value=create, expected_type=type_hints["create"])
             check_type(argname="argument default", value=default, expected_type=type_hints["default"])
             check_type(argname="argument delete", value=delete, expected_type=type_hints["delete"])
             check_type(argname="argument update", value=update, expected_type=type_hints["update"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if create is not None:
             self._values["create"] = create
         if default is not None:
@@ -627,13 +629,13 @@ class DataIonoscloudK8SNodePoolNodesTimeouts:
 
 
 class DataIonoscloudK8SNodePoolNodesTimeoutsOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.dataIonoscloudK8SNodePoolNodes.DataIonoscloudK8SNodePoolNodesTimeoutsOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -641,7 +643,7 @@ class DataIonoscloudK8SNodePoolNodesTimeoutsOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudK8SNodePoolNodesTimeoutsOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__7a392035cdac8e41231cb94b31e4487c6a4e16656c7e1b879bcbe30b2cad84b4)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -690,7 +692,7 @@ class DataIonoscloudK8SNodePoolNodesTimeoutsOutputReference(
     @create.setter
     def create(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudK8SNodePoolNodesTimeoutsOutputReference, "create").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__17a6919f6e31b0120f62d4b34bbc8cd5d1722137a21994613f2e4772472b0d64)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "create", value)
 
@@ -702,7 +704,7 @@ class DataIonoscloudK8SNodePoolNodesTimeoutsOutputReference(
     @default.setter
     def default(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudK8SNodePoolNodesTimeoutsOutputReference, "default").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__19e275cc05f2d57e06c45ea0c9a2d9d2f688550c58ff9de55d01305e0214ed1f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "default", value)
 
@@ -714,7 +716,7 @@ class DataIonoscloudK8SNodePoolNodesTimeoutsOutputReference(
     @delete.setter
     def delete(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudK8SNodePoolNodesTimeoutsOutputReference, "delete").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__14bb1719580a4170d70c7b753228314d0971c224799746930e7718748828a016)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "delete", value)
 
@@ -726,7 +728,7 @@ class DataIonoscloudK8SNodePoolNodesTimeoutsOutputReference(
     @update.setter
     def update(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudK8SNodePoolNodesTimeoutsOutputReference, "update").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__849b18ac89a644b06f02acac08008089326e7b728179dc762c2c334a5ff3d1e5)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "update", value)
 
@@ -734,16 +736,16 @@ class DataIonoscloudK8SNodePoolNodesTimeoutsOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[DataIonoscloudK8SNodePoolNodesTimeouts, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[DataIonoscloudK8SNodePoolNodesTimeouts, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[DataIonoscloudK8SNodePoolNodesTimeouts, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[DataIonoscloudK8SNodePoolNodesTimeouts, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[DataIonoscloudK8SNodePoolNodesTimeouts, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[DataIonoscloudK8SNodePoolNodesTimeouts, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudK8SNodePoolNodesTimeoutsOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__3cd01d8cd3d01a000c08401f4b8837d9d8a8f93978547a04796d4d118fe2f28d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -759,3 +761,151 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__776c7fb2a367ef55914f78551a8aa3f4fcc5187f063e0f95520e3e09fc6ccc6b(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    k8_s_cluster_id: builtins.str,
+    node_pool_id: builtins.str,
+    id: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[DataIonoscloudK8SNodePoolNodesTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__87fe3f45e04c907e18f1f428ee81b563c8614f86a4aef73626be4ea3da10cd37(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__193d032f70210e225259b1ac04a2a0447f96489f1234548b0c5ecf5587dee618(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0851cf38312654281e52df696575e28943cdb792c019503fda7718f41c84a596(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5812b1f013e8d18336abe24aaaab10d6012a5de6e64c844db45dbf92ef2f5a66(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    k8_s_cluster_id: builtins.str,
+    node_pool_id: builtins.str,
+    id: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[DataIonoscloudK8SNodePoolNodesTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__92f02f1b009594f67fe22ea54257746de3c2827fd6744bb9b94fb685e4735055(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    wraps_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__29dee6102d919c589b4939bb772770032986345e8eee0768dc2d18bea10d68c0(
+    index: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bd2db0f660ff71e410d62745ceecbb0dc183d897bea941629f63d1dee7baed94(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5241675fe38e6b71116016db19579d715d0d133e402ee0aa06589a4781d635d1(
+    value: _cdktf_9a9027ec.IInterpolatingParent,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bab34e311c38b93979f01b12db49429c26e26fd5511187704df2774a7ef662d9(
+    value: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8ae17a756bc12305600f80632259d3d722494657cba21db55a0548e98b0311e1(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    complex_object_index: jsii.Number,
+    complex_object_is_from_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__08ccf6bd65b47601f683bf7ffcbd20cb4b7956b228f98a763d905458e1984843(
+    value: typing.Optional[DataIonoscloudK8SNodePoolNodesNodes],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e4a891c7c11ea8ca4d03ada3cdfd75d0ba6bec9741f50a7a104e2c1eba85950f(
+    *,
+    create: typing.Optional[builtins.str] = None,
+    default: typing.Optional[builtins.str] = None,
+    delete: typing.Optional[builtins.str] = None,
+    update: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7a392035cdac8e41231cb94b31e4487c6a4e16656c7e1b879bcbe30b2cad84b4(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__17a6919f6e31b0120f62d4b34bbc8cd5d1722137a21994613f2e4772472b0d64(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__19e275cc05f2d57e06c45ea0c9a2d9d2f688550c58ff9de55d01305e0214ed1f(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__14bb1719580a4170d70c7b753228314d0971c224799746930e7718748828a016(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__849b18ac89a644b06f02acac08008089326e7b728179dc762c2c334a5ff3d1e5(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3cd01d8cd3d01a000c08401f4b8837d9d8a8f93978547a04796d4d118fe2f28d(
+    value: typing.Optional[typing.Union[DataIonoscloudK8SNodePoolNodesTimeouts, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
