@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class DataIonoscloudNic(
-    cdktf.TerraformDataSource,
+    _cdktf_9a9027ec.TerraformDataSource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.dataIonoscloudNic.DataIonoscloudNic",
 ):
@@ -30,26 +30,26 @@ class DataIonoscloudNic(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         datacenter_id: builtins.str,
         server_id: builtins.str,
-        dhcp: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-        firewall_active: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        dhcp: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+        firewall_active: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         firewall_type: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
         ips: typing.Optional[typing.Sequence[builtins.str]] = None,
         lan: typing.Optional[jsii.Number] = None,
         name: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["DataIonoscloudNicTimeouts", typing.Dict[str, typing.Any]]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        timeouts: typing.Optional[typing.Union["DataIonoscloudNicTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/ionoscloud/d/nic ionoscloud_nic} Data Source.
 
@@ -74,7 +74,7 @@ class DataIonoscloudNic(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudNic.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__cbdbbb60a3010c2c972b2fc308836bf59ce6d4c0d9591fd5b87186fdc0581a07)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = DataIonoscloudNicConfig(
@@ -190,15 +190,15 @@ class DataIonoscloudNic(
     @jsii.member(jsii_name="dhcpInput")
     def dhcp_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "dhcpInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "dhcpInput"))
 
     @builtins.property
     @jsii.member(jsii_name="firewallActiveInput")
     def firewall_active_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "firewallActiveInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "firewallActiveInput"))
 
     @builtins.property
     @jsii.member(jsii_name="firewallTypeInput")
@@ -234,8 +234,8 @@ class DataIonoscloudNic(
     @jsii.member(jsii_name="timeoutsInput")
     def timeouts_input(
         self,
-    ) -> typing.Optional[typing.Union["DataIonoscloudNicTimeouts", cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union["DataIonoscloudNicTimeouts", cdktf.IResolvable]], jsii.get(self, "timeoutsInput"))
+    ) -> typing.Optional[typing.Union["DataIonoscloudNicTimeouts", _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union["DataIonoscloudNicTimeouts", _cdktf_9a9027ec.IResolvable]], jsii.get(self, "timeoutsInput"))
 
     @builtins.property
     @jsii.member(jsii_name="datacenterId")
@@ -245,34 +245,39 @@ class DataIonoscloudNic(
     @datacenter_id.setter
     def datacenter_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudNic, "datacenter_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__1f953e310e0f20e423a477e46a676a7eba5fdfe106c34af9337cf90aa12fbb01)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "datacenterId", value)
 
     @builtins.property
     @jsii.member(jsii_name="dhcp")
-    def dhcp(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "dhcp"))
+    def dhcp(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "dhcp"))
 
     @dhcp.setter
-    def dhcp(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+    def dhcp(
+        self,
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+    ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudNic, "dhcp").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__2c645e68e141df084efa8c549511efbcdede597328d91128a733fc45bb80fac1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "dhcp", value)
 
     @builtins.property
     @jsii.member(jsii_name="firewallActive")
-    def firewall_active(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "firewallActive"))
+    def firewall_active(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "firewallActive"))
 
     @firewall_active.setter
     def firewall_active(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudNic, "firewall_active").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__99160c39467d60968e0e94a3b29b661e1c0c93300324b14a7595fb609554f71f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "firewallActive", value)
 
@@ -284,7 +289,7 @@ class DataIonoscloudNic(
     @firewall_type.setter
     def firewall_type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudNic, "firewall_type").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__cfdefe30a0311804df4a51f8d7d5ead8b0c51decc7653e122e403ef6522c5b32)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "firewallType", value)
 
@@ -296,7 +301,7 @@ class DataIonoscloudNic(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudNic, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__b32290588fe750ce67995ac6d0d81b1be53a65f114c2203c7b48b304c84ca82b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -308,7 +313,7 @@ class DataIonoscloudNic(
     @ips.setter
     def ips(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudNic, "ips").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__cfd4bbe28f2171bd023db122425f10f6e84fe2b039724f736cbf2b8b5c416f78)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ips", value)
 
@@ -320,7 +325,7 @@ class DataIonoscloudNic(
     @lan.setter
     def lan(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudNic, "lan").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5466488304259fc4c6f2e7ad0987cc575b4048dc85317d92234bc739694ef6a2)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "lan", value)
 
@@ -332,7 +337,7 @@ class DataIonoscloudNic(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudNic, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__ae768b12b5c9f68006fefb003c0b8c0dacfca562ad8d704502f6e4b48ed32ce9)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -344,14 +349,14 @@ class DataIonoscloudNic(
     @server_id.setter
     def server_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudNic, "server_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__769d09b67dc254e3ef02b53ef201837481a3ad9d62cc561a5c5ef31f2b5cfe46)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "serverId", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-ionoscloud.dataIonoscloudNic.DataIonoscloudNicConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -372,27 +377,27 @@ class DataIonoscloudNic(
         "timeouts": "timeouts",
     },
 )
-class DataIonoscloudNicConfig(cdktf.TerraformMetaArguments):
+class DataIonoscloudNicConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         datacenter_id: builtins.str,
         server_id: builtins.str,
-        dhcp: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-        firewall_active: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        dhcp: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+        firewall_active: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         firewall_type: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
         ips: typing.Optional[typing.Sequence[builtins.str]] = None,
         lan: typing.Optional[jsii.Number] = None,
         name: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["DataIonoscloudNicTimeouts", typing.Dict[str, typing.Any]]] = None,
+        timeouts: typing.Optional[typing.Union["DataIonoscloudNicTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param connection: 
@@ -414,11 +419,11 @@ class DataIonoscloudNicConfig(cdktf.TerraformMetaArguments):
         :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/d/nic#timeouts DataIonoscloudNic#timeouts}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(timeouts, dict):
             timeouts = DataIonoscloudNicTimeouts(**timeouts)
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudNicConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__3d3349ed3e0ef551c149f90a682572c860dd7538f88c818f3e3b79f6a52ce88e)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -436,7 +441,7 @@ class DataIonoscloudNicConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument lan", value=lan, expected_type=type_hints["lan"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument timeouts", value=timeouts, expected_type=type_hints["timeouts"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "datacenter_id": datacenter_id,
             "server_id": server_id,
         }
@@ -474,12 +479,12 @@ class DataIonoscloudNicConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -490,46 +495,48 @@ class DataIonoscloudNicConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def datacenter_id(self) -> builtins.str:
@@ -546,18 +553,20 @@ class DataIonoscloudNicConfig(cdktf.TerraformMetaArguments):
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def dhcp(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    def dhcp(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/d/nic#dhcp DataIonoscloudNic#dhcp}.'''
         result = self._values.get("dhcp")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def firewall_active(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/d/nic#firewall_active DataIonoscloudNic#firewall_active}.'''
         result = self._values.get("firewall_active")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def firewall_type(self) -> typing.Optional[builtins.str]:
@@ -640,12 +649,12 @@ class DataIonoscloudNicTimeouts:
         :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/d/nic#update DataIonoscloudNic#update}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudNicTimeouts.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__db8ae7bd8515aba3f828a8c688f1d02767cd2d30e7ba69d923aa36aaa36734d7)
             check_type(argname="argument create", value=create, expected_type=type_hints["create"])
             check_type(argname="argument default", value=default, expected_type=type_hints["default"])
             check_type(argname="argument delete", value=delete, expected_type=type_hints["delete"])
             check_type(argname="argument update", value=update, expected_type=type_hints["update"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if create is not None:
             self._values["create"] = create
         if default is not None:
@@ -692,13 +701,13 @@ class DataIonoscloudNicTimeouts:
 
 
 class DataIonoscloudNicTimeoutsOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.dataIonoscloudNic.DataIonoscloudNicTimeoutsOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -706,7 +715,7 @@ class DataIonoscloudNicTimeoutsOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudNicTimeoutsOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__46635e2dadaef52e74e33b4e0dc7e3a65d97ef17363b8544d0c4a75dd25a31fd)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -755,7 +764,7 @@ class DataIonoscloudNicTimeoutsOutputReference(
     @create.setter
     def create(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudNicTimeoutsOutputReference, "create").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__186c4a6a3cfda2a95bd7938828a43d921f9acc1e7dd590303af6f16cd212bb89)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "create", value)
 
@@ -767,7 +776,7 @@ class DataIonoscloudNicTimeoutsOutputReference(
     @default.setter
     def default(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudNicTimeoutsOutputReference, "default").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d6f54d649b811023dcbe63ee42346c6f2005d924cb506959998bb97a1f4a1984)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "default", value)
 
@@ -779,7 +788,7 @@ class DataIonoscloudNicTimeoutsOutputReference(
     @delete.setter
     def delete(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudNicTimeoutsOutputReference, "delete").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5d7fbbef29f2456854d15549b25c052ff71c89e17ee5dbe1cf73d2def3b6cfee)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "delete", value)
 
@@ -791,7 +800,7 @@ class DataIonoscloudNicTimeoutsOutputReference(
     @update.setter
     def update(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudNicTimeoutsOutputReference, "update").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__83509ef9e44002dc0d5939929803550be37605e66af2cfd7d19495fd1b64e520)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "update", value)
 
@@ -799,16 +808,16 @@ class DataIonoscloudNicTimeoutsOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[DataIonoscloudNicTimeouts, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[DataIonoscloudNicTimeouts, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[DataIonoscloudNicTimeouts, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[DataIonoscloudNicTimeouts, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[DataIonoscloudNicTimeouts, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[DataIonoscloudNicTimeouts, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudNicTimeoutsOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__50e0b09da057e68244c44408e589ad013f178dd5b3547d1876d708d9aa718932)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -821,3 +830,152 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__cbdbbb60a3010c2c972b2fc308836bf59ce6d4c0d9591fd5b87186fdc0581a07(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    datacenter_id: builtins.str,
+    server_id: builtins.str,
+    dhcp: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    firewall_active: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    firewall_type: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    ips: typing.Optional[typing.Sequence[builtins.str]] = None,
+    lan: typing.Optional[jsii.Number] = None,
+    name: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[DataIonoscloudNicTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1f953e310e0f20e423a477e46a676a7eba5fdfe106c34af9337cf90aa12fbb01(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2c645e68e141df084efa8c549511efbcdede597328d91128a733fc45bb80fac1(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__99160c39467d60968e0e94a3b29b661e1c0c93300324b14a7595fb609554f71f(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cfdefe30a0311804df4a51f8d7d5ead8b0c51decc7653e122e403ef6522c5b32(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b32290588fe750ce67995ac6d0d81b1be53a65f114c2203c7b48b304c84ca82b(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cfd4bbe28f2171bd023db122425f10f6e84fe2b039724f736cbf2b8b5c416f78(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5466488304259fc4c6f2e7ad0987cc575b4048dc85317d92234bc739694ef6a2(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ae768b12b5c9f68006fefb003c0b8c0dacfca562ad8d704502f6e4b48ed32ce9(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__769d09b67dc254e3ef02b53ef201837481a3ad9d62cc561a5c5ef31f2b5cfe46(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3d3349ed3e0ef551c149f90a682572c860dd7538f88c818f3e3b79f6a52ce88e(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    datacenter_id: builtins.str,
+    server_id: builtins.str,
+    dhcp: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    firewall_active: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    firewall_type: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    ips: typing.Optional[typing.Sequence[builtins.str]] = None,
+    lan: typing.Optional[jsii.Number] = None,
+    name: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[DataIonoscloudNicTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__db8ae7bd8515aba3f828a8c688f1d02767cd2d30e7ba69d923aa36aaa36734d7(
+    *,
+    create: typing.Optional[builtins.str] = None,
+    default: typing.Optional[builtins.str] = None,
+    delete: typing.Optional[builtins.str] = None,
+    update: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__46635e2dadaef52e74e33b4e0dc7e3a65d97ef17363b8544d0c4a75dd25a31fd(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__186c4a6a3cfda2a95bd7938828a43d921f9acc1e7dd590303af6f16cd212bb89(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d6f54d649b811023dcbe63ee42346c6f2005d924cb506959998bb97a1f4a1984(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5d7fbbef29f2456854d15549b25c052ff71c89e17ee5dbe1cf73d2def3b6cfee(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__83509ef9e44002dc0d5939929803550be37605e66af2cfd7d19495fd1b64e520(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__50e0b09da057e68244c44408e589ad013f178dd5b3547d1876d708d9aa718932(
+    value: typing.Optional[typing.Union[DataIonoscloudNicTimeouts, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
