@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class DataIonoscloudUser(
-    cdktf.TerraformDataSource,
+    _cdktf_9a9027ec.TerraformDataSource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.dataIonoscloudUser.DataIonoscloudUser",
 ):
@@ -30,19 +30,19 @@ class DataIonoscloudUser(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         email: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["DataIonoscloudUserTimeouts", typing.Dict[str, typing.Any]]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        timeouts: typing.Optional[typing.Union["DataIonoscloudUserTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/ionoscloud/d/user ionoscloud_user} Data Source.
 
@@ -60,7 +60,7 @@ class DataIonoscloudUser(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudUser.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__1902d69bbdc2e86983fab88c7f2499c91f2c3a4fe22a7fb89cf9cf849c4609f1)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = DataIonoscloudUserConfig(
@@ -122,13 +122,13 @@ class DataIonoscloudUser(
 
     @builtins.property
     @jsii.member(jsii_name="active")
-    def active(self) -> cdktf.IResolvable:
-        return typing.cast(cdktf.IResolvable, jsii.get(self, "active"))
+    def active(self) -> _cdktf_9a9027ec.IResolvable:
+        return typing.cast(_cdktf_9a9027ec.IResolvable, jsii.get(self, "active"))
 
     @builtins.property
     @jsii.member(jsii_name="administrator")
-    def administrator(self) -> cdktf.IResolvable:
-        return typing.cast(cdktf.IResolvable, jsii.get(self, "administrator"))
+    def administrator(self) -> _cdktf_9a9027ec.IResolvable:
+        return typing.cast(_cdktf_9a9027ec.IResolvable, jsii.get(self, "administrator"))
 
     @builtins.property
     @jsii.member(jsii_name="firstName")
@@ -137,8 +137,8 @@ class DataIonoscloudUser(
 
     @builtins.property
     @jsii.member(jsii_name="forceSecAuth")
-    def force_sec_auth(self) -> cdktf.IResolvable:
-        return typing.cast(cdktf.IResolvable, jsii.get(self, "forceSecAuth"))
+    def force_sec_auth(self) -> _cdktf_9a9027ec.IResolvable:
+        return typing.cast(_cdktf_9a9027ec.IResolvable, jsii.get(self, "forceSecAuth"))
 
     @builtins.property
     @jsii.member(jsii_name="groups")
@@ -157,8 +157,8 @@ class DataIonoscloudUser(
 
     @builtins.property
     @jsii.member(jsii_name="secAuthActive")
-    def sec_auth_active(self) -> cdktf.IResolvable:
-        return typing.cast(cdktf.IResolvable, jsii.get(self, "secAuthActive"))
+    def sec_auth_active(self) -> _cdktf_9a9027ec.IResolvable:
+        return typing.cast(_cdktf_9a9027ec.IResolvable, jsii.get(self, "secAuthActive"))
 
     @builtins.property
     @jsii.member(jsii_name="timeouts")
@@ -179,8 +179,8 @@ class DataIonoscloudUser(
     @jsii.member(jsii_name="timeoutsInput")
     def timeouts_input(
         self,
-    ) -> typing.Optional[typing.Union["DataIonoscloudUserTimeouts", cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union["DataIonoscloudUserTimeouts", cdktf.IResolvable]], jsii.get(self, "timeoutsInput"))
+    ) -> typing.Optional[typing.Union["DataIonoscloudUserTimeouts", _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union["DataIonoscloudUserTimeouts", _cdktf_9a9027ec.IResolvable]], jsii.get(self, "timeoutsInput"))
 
     @builtins.property
     @jsii.member(jsii_name="email")
@@ -190,7 +190,7 @@ class DataIonoscloudUser(
     @email.setter
     def email(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudUser, "email").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__4296af5ad0ad95844e50dab02a007b77dca57d69bb3b20a45d6d86b687a7eae9)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "email", value)
 
@@ -202,14 +202,14 @@ class DataIonoscloudUser(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudUser, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__ef94eeefb9ebac6d2f7315547650332337b7232966625f5e09f547781b5c01da)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-ionoscloud.dataIonoscloudUser.DataIonoscloudUserConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -223,20 +223,20 @@ class DataIonoscloudUser(
         "timeouts": "timeouts",
     },
 )
-class DataIonoscloudUserConfig(cdktf.TerraformMetaArguments):
+class DataIonoscloudUserConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         email: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["DataIonoscloudUserTimeouts", typing.Dict[str, typing.Any]]] = None,
+        timeouts: typing.Optional[typing.Union["DataIonoscloudUserTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param connection: 
@@ -251,11 +251,11 @@ class DataIonoscloudUserConfig(cdktf.TerraformMetaArguments):
         :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/d/user#timeouts DataIonoscloudUser#timeouts}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(timeouts, dict):
             timeouts = DataIonoscloudUserTimeouts(**timeouts)
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudUserConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__a1086a63f9a70bf942fd13fa34c06c514096ac6a3e8c077fdf1737fb154435d2)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -266,7 +266,7 @@ class DataIonoscloudUserConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument email", value=email, expected_type=type_hints["email"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument timeouts", value=timeouts, expected_type=type_hints["timeouts"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if connection is not None:
             self._values["connection"] = connection
         if count is not None:
@@ -291,12 +291,12 @@ class DataIonoscloudUserConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -307,46 +307,48 @@ class DataIonoscloudUserConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def email(self) -> typing.Optional[builtins.str]:
@@ -392,7 +394,7 @@ class DataIonoscloudUserConfig(cdktf.TerraformMetaArguments):
 )
 class DataIonoscloudUserGroups:
     def __init__(self) -> None:
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -407,13 +409,13 @@ class DataIonoscloudUserGroups:
 
 
 class DataIonoscloudUserGroupsList(
-    cdktf.ComplexList,
+    _cdktf_9a9027ec.ComplexList,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.dataIonoscloudUser.DataIonoscloudUserGroupsList",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         wraps_set: builtins.bool,
     ) -> None:
@@ -423,7 +425,7 @@ class DataIonoscloudUserGroupsList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudUserGroupsList.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__f7cee46351ccb0832c68641d931da196561eb8b279ac459acda66f7d94343f78)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -435,7 +437,7 @@ class DataIonoscloudUserGroupsList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudUserGroupsList.get)
+            type_hints = typing.get_type_hints(_typecheckingstub__1e13a388faaaf689ba23f11925db1e4aea9b275f6c3825a44bc58199b76a5e3d)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("DataIonoscloudUserGroupsOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -448,20 +450,20 @@ class DataIonoscloudUserGroupsList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudUserGroupsList, "_terraform_attribute").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__9e8ebfbbc1b9def53de8b4b2f11eab3456f6ca66c900c676d540da17bbfd084f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
     @builtins.property
     @jsii.member(jsii_name="terraformResource")
-    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
+    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
         '''The parent resource.'''
-        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))
+        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))
 
     @_terraform_resource.setter
-    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
+    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudUserGroupsList, "_terraform_resource").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__ff95a46617069b03cef21007ced601be1dc42d4a0337d2aa5ebd50e47a6fb939)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -474,19 +476,19 @@ class DataIonoscloudUserGroupsList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudUserGroupsList, "_wraps_set").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__cd78fc7981b6f55e149c26fd2ab2dcacb0cf3c58ae9bb519b286479550a087fe)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
 
 class DataIonoscloudUserGroupsOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.dataIonoscloudUser.DataIonoscloudUserGroupsOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         complex_object_index: jsii.Number,
         complex_object_is_from_set: builtins.bool,
@@ -498,7 +500,7 @@ class DataIonoscloudUserGroupsOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudUserGroupsOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__9649d7726cbb7915bc3b44dbdb4eef36fc988b54d12f76adddbb8c7147a36db5)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -523,7 +525,7 @@ class DataIonoscloudUserGroupsOutputReference(
     @internal_value.setter
     def internal_value(self, value: typing.Optional[DataIonoscloudUserGroups]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudUserGroupsOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__e3746b9827bb233e0379506de93a5acf818d669082487a22dcaef5445de0e005)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -554,12 +556,12 @@ class DataIonoscloudUserTimeouts:
         :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/d/user#update DataIonoscloudUser#update}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudUserTimeouts.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__a75a2922e0f46fa1a1200103c91cce78f53fd9c52b4b0fe4a857717da57631c9)
             check_type(argname="argument create", value=create, expected_type=type_hints["create"])
             check_type(argname="argument default", value=default, expected_type=type_hints["default"])
             check_type(argname="argument delete", value=delete, expected_type=type_hints["delete"])
             check_type(argname="argument update", value=update, expected_type=type_hints["update"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if create is not None:
             self._values["create"] = create
         if default is not None:
@@ -606,13 +608,13 @@ class DataIonoscloudUserTimeouts:
 
 
 class DataIonoscloudUserTimeoutsOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.dataIonoscloudUser.DataIonoscloudUserTimeoutsOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -620,7 +622,7 @@ class DataIonoscloudUserTimeoutsOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataIonoscloudUserTimeoutsOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__b9ffa60c05fc2d7106a86451a51a65a0cf26d2f4483138dda76f89ce9c7c4b2f)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -669,7 +671,7 @@ class DataIonoscloudUserTimeoutsOutputReference(
     @create.setter
     def create(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudUserTimeoutsOutputReference, "create").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__c9e96effd8b8d66aed761ccff086260ca5f248ba5936c6b2738e405881449e3b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "create", value)
 
@@ -681,7 +683,7 @@ class DataIonoscloudUserTimeoutsOutputReference(
     @default.setter
     def default(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudUserTimeoutsOutputReference, "default").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__74882053839bbc155fb288057bf4a97e40d20d38e1197fb723593765d074da2f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "default", value)
 
@@ -693,7 +695,7 @@ class DataIonoscloudUserTimeoutsOutputReference(
     @delete.setter
     def delete(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudUserTimeoutsOutputReference, "delete").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__580abff9e7dce09ef168167a472b56ddf46c0122070701855f62bbab1c5699d0)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "delete", value)
 
@@ -705,7 +707,7 @@ class DataIonoscloudUserTimeoutsOutputReference(
     @update.setter
     def update(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudUserTimeoutsOutputReference, "update").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__59602c32f3a01f4620d47390211249bbd6b67a676ed7d725e667a73cfa69b01f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "update", value)
 
@@ -713,16 +715,16 @@ class DataIonoscloudUserTimeoutsOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[DataIonoscloudUserTimeouts, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[DataIonoscloudUserTimeouts, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[DataIonoscloudUserTimeouts, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[DataIonoscloudUserTimeouts, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[DataIonoscloudUserTimeouts, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[DataIonoscloudUserTimeouts, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataIonoscloudUserTimeoutsOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5876abfc8bf3e5a63dbfcc1f93ebb3550a239b3ca65ae5f6dde9ff17cda82838)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -738,3 +740,143 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__1902d69bbdc2e86983fab88c7f2499c91f2c3a4fe22a7fb89cf9cf849c4609f1(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    email: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[DataIonoscloudUserTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4296af5ad0ad95844e50dab02a007b77dca57d69bb3b20a45d6d86b687a7eae9(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ef94eeefb9ebac6d2f7315547650332337b7232966625f5e09f547781b5c01da(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a1086a63f9a70bf942fd13fa34c06c514096ac6a3e8c077fdf1737fb154435d2(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    email: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[DataIonoscloudUserTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f7cee46351ccb0832c68641d931da196561eb8b279ac459acda66f7d94343f78(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    wraps_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1e13a388faaaf689ba23f11925db1e4aea9b275f6c3825a44bc58199b76a5e3d(
+    index: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9e8ebfbbc1b9def53de8b4b2f11eab3456f6ca66c900c676d540da17bbfd084f(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ff95a46617069b03cef21007ced601be1dc42d4a0337d2aa5ebd50e47a6fb939(
+    value: _cdktf_9a9027ec.IInterpolatingParent,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cd78fc7981b6f55e149c26fd2ab2dcacb0cf3c58ae9bb519b286479550a087fe(
+    value: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9649d7726cbb7915bc3b44dbdb4eef36fc988b54d12f76adddbb8c7147a36db5(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    complex_object_index: jsii.Number,
+    complex_object_is_from_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e3746b9827bb233e0379506de93a5acf818d669082487a22dcaef5445de0e005(
+    value: typing.Optional[DataIonoscloudUserGroups],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a75a2922e0f46fa1a1200103c91cce78f53fd9c52b4b0fe4a857717da57631c9(
+    *,
+    create: typing.Optional[builtins.str] = None,
+    default: typing.Optional[builtins.str] = None,
+    delete: typing.Optional[builtins.str] = None,
+    update: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b9ffa60c05fc2d7106a86451a51a65a0cf26d2f4483138dda76f89ce9c7c4b2f(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c9e96effd8b8d66aed761ccff086260ca5f248ba5936c6b2738e405881449e3b(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__74882053839bbc155fb288057bf4a97e40d20d38e1197fb723593765d074da2f(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__580abff9e7dce09ef168167a472b56ddf46c0122070701855f62bbab1c5699d0(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__59602c32f3a01f4620d47390211249bbd6b67a676ed7d725e667a73cfa69b01f(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5876abfc8bf3e5a63dbfcc1f93ebb3550a239b3ca65ae5f6dde9ff17cda82838(
+    value: typing.Optional[typing.Union[DataIonoscloudUserTimeouts, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
