@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class Firewall(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.firewall.Firewall",
 ):
@@ -30,7 +30,7 @@ class Firewall(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         datacenter_id: builtins.str,
@@ -46,15 +46,15 @@ class Firewall(
         source_ip: typing.Optional[builtins.str] = None,
         source_mac: typing.Optional[builtins.str] = None,
         target_ip: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["FirewallTimeouts", typing.Dict[str, typing.Any]]] = None,
+        timeouts: typing.Optional[typing.Union["FirewallTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
         type: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/ionoscloud/r/firewall ionoscloud_firewall} Resource.
 
@@ -84,7 +84,7 @@ class Firewall(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Firewall.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__88f0b74d27a180dec1e361c7cdecfd44d18305b8a1354040814bfde552155b48)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = FirewallConfig(
@@ -262,8 +262,8 @@ class Firewall(
     @jsii.member(jsii_name="timeoutsInput")
     def timeouts_input(
         self,
-    ) -> typing.Optional[typing.Union["FirewallTimeouts", cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union["FirewallTimeouts", cdktf.IResolvable]], jsii.get(self, "timeoutsInput"))
+    ) -> typing.Optional[typing.Union["FirewallTimeouts", _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union["FirewallTimeouts", _cdktf_9a9027ec.IResolvable]], jsii.get(self, "timeoutsInput"))
 
     @builtins.property
     @jsii.member(jsii_name="typeInput")
@@ -278,7 +278,7 @@ class Firewall(
     @datacenter_id.setter
     def datacenter_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Firewall, "datacenter_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__061f0ad63f97a908db874d0b8c1d23ebcdd78cabe186499e91546ce1e6652df7)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "datacenterId", value)
 
@@ -290,7 +290,7 @@ class Firewall(
     @icmp_code.setter
     def icmp_code(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Firewall, "icmp_code").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__9611a2248146020f268f3ddde8f0d17e249d2681e15b3604a54e1a01f7782c2e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "icmpCode", value)
 
@@ -302,7 +302,7 @@ class Firewall(
     @icmp_type.setter
     def icmp_type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Firewall, "icmp_type").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__25ae3969e0479540e76343ef8d8a9a5f2adeefb7dc530ee255f606746b30051b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "icmpType", value)
 
@@ -314,7 +314,7 @@ class Firewall(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Firewall, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__35167c654bd138c440e3c3dea75b86fb7f5207c9f1b068c02ada4f9dc69dfbba)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -326,7 +326,7 @@ class Firewall(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Firewall, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__87fe5037308b10da7f9db428eb1a51d9078da2863cf8fa848e858fdf04ce2027)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -338,7 +338,7 @@ class Firewall(
     @nic_id.setter
     def nic_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Firewall, "nic_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__8ed8ca4a3f43c7171d7668ad6cd4d76542d1614c46470703fd5d9069d84633b1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "nicId", value)
 
@@ -350,7 +350,7 @@ class Firewall(
     @port_range_end.setter
     def port_range_end(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Firewall, "port_range_end").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__3cf04e72522664f0cf0dd8ec43713510a2f1d2d31bf6f52353cc2c92533ff56b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "portRangeEnd", value)
 
@@ -362,7 +362,7 @@ class Firewall(
     @port_range_start.setter
     def port_range_start(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Firewall, "port_range_start").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7e3dc3fd98ecb7281d82c9f53937708f8ddbc3620ed531b2eba40bf153789a27)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "portRangeStart", value)
 
@@ -374,7 +374,7 @@ class Firewall(
     @protocol.setter
     def protocol(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Firewall, "protocol").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d41a7d683610346ecfdfc9f94ef4e58d89533cdba1255a5b920eeb2ff335e5cc)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "protocol", value)
 
@@ -386,7 +386,7 @@ class Firewall(
     @server_id.setter
     def server_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Firewall, "server_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5137890a285106e408483895c4e46f2c70d099c0cf59baa02cce10c977de3a98)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "serverId", value)
 
@@ -398,7 +398,7 @@ class Firewall(
     @source_ip.setter
     def source_ip(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Firewall, "source_ip").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__6e9e6e808724601a54f7388e9f13fee613d8e4b03772141f54cee226b5d90b84)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sourceIp", value)
 
@@ -410,7 +410,7 @@ class Firewall(
     @source_mac.setter
     def source_mac(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Firewall, "source_mac").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__4e11900e2301f75205ceb7b222d193d683280b3406585a4819ed6210a6796783)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sourceMac", value)
 
@@ -422,7 +422,7 @@ class Firewall(
     @target_ip.setter
     def target_ip(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Firewall, "target_ip").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__35adb510eafa4899fd4f9d05d9e4c1bdcff29aea196d4f716db0138a0af3cdab)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "targetIp", value)
 
@@ -434,14 +434,14 @@ class Firewall(
     @type.setter
     def type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Firewall, "type").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7db10bb1a4471ad192d63441dacf4063267991134730dbc8040ddec0e49d215f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "type", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-ionoscloud.firewall.FirewallConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -467,17 +467,17 @@ class Firewall(
         "type": "type",
     },
 )
-class FirewallConfig(cdktf.TerraformMetaArguments):
+class FirewallConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         datacenter_id: builtins.str,
         nic_id: builtins.str,
         protocol: builtins.str,
@@ -491,7 +491,7 @@ class FirewallConfig(cdktf.TerraformMetaArguments):
         source_ip: typing.Optional[builtins.str] = None,
         source_mac: typing.Optional[builtins.str] = None,
         target_ip: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["FirewallTimeouts", typing.Dict[str, typing.Any]]] = None,
+        timeouts: typing.Optional[typing.Union["FirewallTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
         type: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -519,11 +519,11 @@ class FirewallConfig(cdktf.TerraformMetaArguments):
         :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/r/firewall#type Firewall#type}.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(timeouts, dict):
             timeouts = FirewallTimeouts(**timeouts)
         if __debug__:
-            type_hints = typing.get_type_hints(FirewallConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__136d28ac3628fbf3081b79560d2c6b51d3bf1b8f9d8186a3931778d864d48968)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -546,7 +546,7 @@ class FirewallConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument target_ip", value=target_ip, expected_type=type_hints["target_ip"])
             check_type(argname="argument timeouts", value=timeouts, expected_type=type_hints["timeouts"])
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "datacenter_id": datacenter_id,
             "nic_id": nic_id,
             "protocol": protocol,
@@ -592,12 +592,12 @@ class FirewallConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -608,46 +608,48 @@ class FirewallConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def datacenter_id(self) -> builtins.str:
@@ -788,12 +790,12 @@ class FirewallTimeouts:
         :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/r/firewall#update Firewall#update}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FirewallTimeouts.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__0040ae7b9f279c6dfc9e4ad45488df3d977b1038faefceb5b0cd75668a9e7949)
             check_type(argname="argument create", value=create, expected_type=type_hints["create"])
             check_type(argname="argument default", value=default, expected_type=type_hints["default"])
             check_type(argname="argument delete", value=delete, expected_type=type_hints["delete"])
             check_type(argname="argument update", value=update, expected_type=type_hints["update"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if create is not None:
             self._values["create"] = create
         if default is not None:
@@ -840,13 +842,13 @@ class FirewallTimeouts:
 
 
 class FirewallTimeoutsOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.firewall.FirewallTimeoutsOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -854,7 +856,7 @@ class FirewallTimeoutsOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FirewallTimeoutsOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__2445acb276edd840a7e043ce2c18fbd3f20566c74e80f5e3fc5e8c0b5e44ced0)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -903,7 +905,7 @@ class FirewallTimeoutsOutputReference(
     @create.setter
     def create(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallTimeoutsOutputReference, "create").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__fa46040d73a6e5bdc3993a41231b4a4388a49b69ffef75e8eb5df725064f8f55)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "create", value)
 
@@ -915,7 +917,7 @@ class FirewallTimeoutsOutputReference(
     @default.setter
     def default(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallTimeoutsOutputReference, "default").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__42d68b2cefcde72e968ebf0ce565de5bcf735761cea6a8802928bc0f0de22d8c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "default", value)
 
@@ -927,7 +929,7 @@ class FirewallTimeoutsOutputReference(
     @delete.setter
     def delete(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallTimeoutsOutputReference, "delete").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__67c7ffc09501b0b77a37af15d5dd7b9f18f1a43548cf8a903971aa835a88bc6f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "delete", value)
 
@@ -939,7 +941,7 @@ class FirewallTimeoutsOutputReference(
     @update.setter
     def update(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallTimeoutsOutputReference, "update").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__3949d44446a99a3913abc03a6eae9b4e7c6fb301ede70683cc48fab7397a300f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "update", value)
 
@@ -947,16 +949,16 @@ class FirewallTimeoutsOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[FirewallTimeouts, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[FirewallTimeouts, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[FirewallTimeouts, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[FirewallTimeouts, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[FirewallTimeouts, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[FirewallTimeouts, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FirewallTimeoutsOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__ceedae92979d6eb09bacb8a6bbbbef572e41ea04182282138841c6a18213585f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -969,3 +971,192 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__88f0b74d27a180dec1e361c7cdecfd44d18305b8a1354040814bfde552155b48(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    datacenter_id: builtins.str,
+    nic_id: builtins.str,
+    protocol: builtins.str,
+    server_id: builtins.str,
+    icmp_code: typing.Optional[builtins.str] = None,
+    icmp_type: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    name: typing.Optional[builtins.str] = None,
+    port_range_end: typing.Optional[jsii.Number] = None,
+    port_range_start: typing.Optional[jsii.Number] = None,
+    source_ip: typing.Optional[builtins.str] = None,
+    source_mac: typing.Optional[builtins.str] = None,
+    target_ip: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[FirewallTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+    type: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__061f0ad63f97a908db874d0b8c1d23ebcdd78cabe186499e91546ce1e6652df7(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9611a2248146020f268f3ddde8f0d17e249d2681e15b3604a54e1a01f7782c2e(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__25ae3969e0479540e76343ef8d8a9a5f2adeefb7dc530ee255f606746b30051b(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__35167c654bd138c440e3c3dea75b86fb7f5207c9f1b068c02ada4f9dc69dfbba(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__87fe5037308b10da7f9db428eb1a51d9078da2863cf8fa848e858fdf04ce2027(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8ed8ca4a3f43c7171d7668ad6cd4d76542d1614c46470703fd5d9069d84633b1(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3cf04e72522664f0cf0dd8ec43713510a2f1d2d31bf6f52353cc2c92533ff56b(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7e3dc3fd98ecb7281d82c9f53937708f8ddbc3620ed531b2eba40bf153789a27(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d41a7d683610346ecfdfc9f94ef4e58d89533cdba1255a5b920eeb2ff335e5cc(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5137890a285106e408483895c4e46f2c70d099c0cf59baa02cce10c977de3a98(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6e9e6e808724601a54f7388e9f13fee613d8e4b03772141f54cee226b5d90b84(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4e11900e2301f75205ceb7b222d193d683280b3406585a4819ed6210a6796783(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__35adb510eafa4899fd4f9d05d9e4c1bdcff29aea196d4f716db0138a0af3cdab(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7db10bb1a4471ad192d63441dacf4063267991134730dbc8040ddec0e49d215f(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__136d28ac3628fbf3081b79560d2c6b51d3bf1b8f9d8186a3931778d864d48968(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    datacenter_id: builtins.str,
+    nic_id: builtins.str,
+    protocol: builtins.str,
+    server_id: builtins.str,
+    icmp_code: typing.Optional[builtins.str] = None,
+    icmp_type: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    name: typing.Optional[builtins.str] = None,
+    port_range_end: typing.Optional[jsii.Number] = None,
+    port_range_start: typing.Optional[jsii.Number] = None,
+    source_ip: typing.Optional[builtins.str] = None,
+    source_mac: typing.Optional[builtins.str] = None,
+    target_ip: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[FirewallTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+    type: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0040ae7b9f279c6dfc9e4ad45488df3d977b1038faefceb5b0cd75668a9e7949(
+    *,
+    create: typing.Optional[builtins.str] = None,
+    default: typing.Optional[builtins.str] = None,
+    delete: typing.Optional[builtins.str] = None,
+    update: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2445acb276edd840a7e043ce2c18fbd3f20566c74e80f5e3fc5e8c0b5e44ced0(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fa46040d73a6e5bdc3993a41231b4a4388a49b69ffef75e8eb5df725064f8f55(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__42d68b2cefcde72e968ebf0ce565de5bcf735761cea6a8802928bc0f0de22d8c(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__67c7ffc09501b0b77a37af15d5dd7b9f18f1a43548cf8a903971aa835a88bc6f(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3949d44446a99a3913abc03a6eae9b4e7c6fb301ede70683cc48fab7397a300f(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ceedae92979d6eb09bacb8a6bbbbef572e41ea04182282138841c6a18213585f(
+    value: typing.Optional[typing.Union[FirewallTimeouts, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
