@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class Ipblock(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.ipblock.Ipblock",
 ):
@@ -30,22 +30,22 @@ class Ipblock(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         location: builtins.str,
         size: jsii.Number,
         id: typing.Optional[builtins.str] = None,
-        ip_consumers: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["IpblockIpConsumers", typing.Dict[str, typing.Any]]]]] = None,
+        ip_consumers: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["IpblockIpConsumers", typing.Dict[builtins.str, typing.Any]]]]] = None,
         name: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["IpblockTimeouts", typing.Dict[str, typing.Any]]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        timeouts: typing.Optional[typing.Union["IpblockTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/ionoscloud/r/ipblock ionoscloud_ipblock} Resource.
 
@@ -66,7 +66,7 @@ class Ipblock(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Ipblock.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__090a1607df1c46c8c27f052d1e414c5cf3b2436302dee00378207993d87d67ee)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = IpblockConfig(
@@ -90,13 +90,13 @@ class Ipblock(
     @jsii.member(jsii_name="putIpConsumers")
     def put_ip_consumers(
         self,
-        value: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["IpblockIpConsumers", typing.Dict[str, typing.Any]]]],
+        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["IpblockIpConsumers", typing.Dict[builtins.str, typing.Any]]]],
     ) -> None:
         '''
         :param value: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Ipblock.put_ip_consumers)
+            type_hints = typing.get_type_hints(_typecheckingstub__5317c495ec20ea3ac4c0dfbf71a9d9fac89a370529dd9ec85320eed1ff625b88)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(None, jsii.invoke(self, "putIpConsumers", [value]))
 
@@ -170,8 +170,8 @@ class Ipblock(
     @jsii.member(jsii_name="ipConsumersInput")
     def ip_consumers_input(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["IpblockIpConsumers"]]]:
-        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["IpblockIpConsumers"]]], jsii.get(self, "ipConsumersInput"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["IpblockIpConsumers"]]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["IpblockIpConsumers"]]], jsii.get(self, "ipConsumersInput"))
 
     @builtins.property
     @jsii.member(jsii_name="locationInput")
@@ -192,8 +192,8 @@ class Ipblock(
     @jsii.member(jsii_name="timeoutsInput")
     def timeouts_input(
         self,
-    ) -> typing.Optional[typing.Union["IpblockTimeouts", cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union["IpblockTimeouts", cdktf.IResolvable]], jsii.get(self, "timeoutsInput"))
+    ) -> typing.Optional[typing.Union["IpblockTimeouts", _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union["IpblockTimeouts", _cdktf_9a9027ec.IResolvable]], jsii.get(self, "timeoutsInput"))
 
     @builtins.property
     @jsii.member(jsii_name="id")
@@ -203,7 +203,7 @@ class Ipblock(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Ipblock, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__45df909985d7710dff82477cbda9b29a68333854adc8004b51ba1aabaeff27f7)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -215,7 +215,7 @@ class Ipblock(
     @location.setter
     def location(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Ipblock, "location").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__f31612203fdcab1b52d339cac32268ee89f6379fedefa36dc39673df9ad506ba)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "location", value)
 
@@ -227,7 +227,7 @@ class Ipblock(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Ipblock, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d9ccd329250c5d627b83296492d071fba5a935d8047589977e049d83783200be)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -239,14 +239,14 @@ class Ipblock(
     @size.setter
     def size(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Ipblock, "size").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__112a714bc828ea93a8ced59e1f71be5af3c5042f334b5e4671cba0072bb3a348)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "size", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-ionoscloud.ipblock.IpblockConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -263,23 +263,23 @@ class Ipblock(
         "timeouts": "timeouts",
     },
 )
-class IpblockConfig(cdktf.TerraformMetaArguments):
+class IpblockConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         location: builtins.str,
         size: jsii.Number,
         id: typing.Optional[builtins.str] = None,
-        ip_consumers: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["IpblockIpConsumers", typing.Dict[str, typing.Any]]]]] = None,
+        ip_consumers: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["IpblockIpConsumers", typing.Dict[builtins.str, typing.Any]]]]] = None,
         name: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["IpblockTimeouts", typing.Dict[str, typing.Any]]] = None,
+        timeouts: typing.Optional[typing.Union["IpblockTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param connection: 
@@ -297,11 +297,11 @@ class IpblockConfig(cdktf.TerraformMetaArguments):
         :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/r/ipblock#timeouts Ipblock#timeouts}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(timeouts, dict):
             timeouts = IpblockTimeouts(**timeouts)
         if __debug__:
-            type_hints = typing.get_type_hints(IpblockConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__cffed96ee07439c94a9f6a4c75ac70de6b6a89c108940a975e87e0505c68b96f)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -315,7 +315,7 @@ class IpblockConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument ip_consumers", value=ip_consumers, expected_type=type_hints["ip_consumers"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument timeouts", value=timeouts, expected_type=type_hints["timeouts"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "location": location,
             "size": size,
         }
@@ -345,12 +345,12 @@ class IpblockConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -361,46 +361,48 @@ class IpblockConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def location(self) -> builtins.str:
@@ -429,13 +431,13 @@ class IpblockConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def ip_consumers(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["IpblockIpConsumers"]]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["IpblockIpConsumers"]]]:
         '''ip_consumers block.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/r/ipblock#ip_consumers Ipblock#ip_consumers}
         '''
         result = self._values.get("ip_consumers")
-        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["IpblockIpConsumers"]]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["IpblockIpConsumers"]]], result)
 
     @builtins.property
     def name(self) -> typing.Optional[builtins.str]:
@@ -471,7 +473,7 @@ class IpblockConfig(cdktf.TerraformMetaArguments):
 )
 class IpblockIpConsumers:
     def __init__(self) -> None:
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -486,13 +488,13 @@ class IpblockIpConsumers:
 
 
 class IpblockIpConsumersList(
-    cdktf.ComplexList,
+    _cdktf_9a9027ec.ComplexList,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.ipblock.IpblockIpConsumersList",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         wraps_set: builtins.bool,
     ) -> None:
@@ -502,7 +504,7 @@ class IpblockIpConsumersList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IpblockIpConsumersList.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__a4679ca26966553fb1eb04ed733d8c0cce22b6eba7eeeaf3add5691776ebf124)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -514,7 +516,7 @@ class IpblockIpConsumersList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IpblockIpConsumersList.get)
+            type_hints = typing.get_type_hints(_typecheckingstub__627ee3094f92b1723e9330c4a514e01f38d124701a196b46c1297ad94d5aedfd)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("IpblockIpConsumersOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -527,20 +529,20 @@ class IpblockIpConsumersList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(IpblockIpConsumersList, "_terraform_attribute").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__536658ce10d9cab682fcbc15e8214a73d21e55c621366baaf109df1752bf209f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
     @builtins.property
     @jsii.member(jsii_name="terraformResource")
-    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
+    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
         '''The parent resource.'''
-        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))
+        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))
 
     @_terraform_resource.setter
-    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
+    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(IpblockIpConsumersList, "_terraform_resource").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__90cc3bde2be2292aebe5a2b3b36b67eff20f4f24022e4f4a11313e48c90ae76c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -553,7 +555,7 @@ class IpblockIpConsumersList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(IpblockIpConsumersList, "_wraps_set").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__0a34510b9c903a5f13e3f8a65a9f83dcefbe722361f700964c9bbcfe766f14ee)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
@@ -561,28 +563,28 @@ class IpblockIpConsumersList(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[IpblockIpConsumers]]]:
-        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[IpblockIpConsumers]]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[IpblockIpConsumers]]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[IpblockIpConsumers]]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[IpblockIpConsumers]]],
+        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[IpblockIpConsumers]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(IpblockIpConsumersList, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__2ea4e4de4cc0c7955d508c06686532e74d9d3dd58d790fc1f28ebf7454e6a21c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
 
 class IpblockIpConsumersOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.ipblock.IpblockIpConsumersOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         complex_object_index: jsii.Number,
         complex_object_is_from_set: builtins.bool,
@@ -594,7 +596,7 @@ class IpblockIpConsumersOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IpblockIpConsumersOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__f2aa45d5414decbe84662084667f5ca8ea96d38c953197cdaae44a19b21b565f)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -650,16 +652,16 @@ class IpblockIpConsumersOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[IpblockIpConsumers, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[IpblockIpConsumers, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[IpblockIpConsumers, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[IpblockIpConsumers, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[IpblockIpConsumers, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[IpblockIpConsumers, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(IpblockIpConsumersOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__65ef6a9a6a740ca507f6cc45b92a675b904faba3df1455826ec1a1b5c7365239)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -690,12 +692,12 @@ class IpblockTimeouts:
         :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/r/ipblock#update Ipblock#update}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IpblockTimeouts.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__22a759e3956a9cf72d78cb091a9cc3cbb975e84f07c1e3f51a8d207fad590039)
             check_type(argname="argument create", value=create, expected_type=type_hints["create"])
             check_type(argname="argument default", value=default, expected_type=type_hints["default"])
             check_type(argname="argument delete", value=delete, expected_type=type_hints["delete"])
             check_type(argname="argument update", value=update, expected_type=type_hints["update"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if create is not None:
             self._values["create"] = create
         if default is not None:
@@ -742,13 +744,13 @@ class IpblockTimeouts:
 
 
 class IpblockTimeoutsOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.ipblock.IpblockTimeoutsOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -756,7 +758,7 @@ class IpblockTimeoutsOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IpblockTimeoutsOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__bfce2652ce2f0711bc529eebe652dd41714a309cb2a512eedca66249da248d70)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -805,7 +807,7 @@ class IpblockTimeoutsOutputReference(
     @create.setter
     def create(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(IpblockTimeoutsOutputReference, "create").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__dd0dca060497554a5cef3ff7900ceb4cc3ff86eba5698d2609a1c143de29f22b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "create", value)
 
@@ -817,7 +819,7 @@ class IpblockTimeoutsOutputReference(
     @default.setter
     def default(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(IpblockTimeoutsOutputReference, "default").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__233ea2d435904f5d7a238902fa542d3123c9400fc05cd22e2b3101fa151c93bb)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "default", value)
 
@@ -829,7 +831,7 @@ class IpblockTimeoutsOutputReference(
     @delete.setter
     def delete(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(IpblockTimeoutsOutputReference, "delete").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__210384728d28cf355d19dc15d192902f7b967acc0e6b822763437699a34a7e4b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "delete", value)
 
@@ -841,7 +843,7 @@ class IpblockTimeoutsOutputReference(
     @update.setter
     def update(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(IpblockTimeoutsOutputReference, "update").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__df966f78b473703dd5191315a10b9b32b665248ff7bd7ae8b87fa8795b63b9ae)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "update", value)
 
@@ -849,16 +851,16 @@ class IpblockTimeoutsOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[IpblockTimeouts, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[IpblockTimeouts, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[IpblockTimeouts, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[IpblockTimeouts, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[IpblockTimeouts, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[IpblockTimeouts, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(IpblockTimeoutsOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__380bdb114d61ab3640416b0550a03c1263426c493502b62972471692001d0471)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -874,3 +876,173 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__090a1607df1c46c8c27f052d1e414c5cf3b2436302dee00378207993d87d67ee(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    location: builtins.str,
+    size: jsii.Number,
+    id: typing.Optional[builtins.str] = None,
+    ip_consumers: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[IpblockIpConsumers, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    name: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[IpblockTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5317c495ec20ea3ac4c0dfbf71a9d9fac89a370529dd9ec85320eed1ff625b88(
+    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[IpblockIpConsumers, typing.Dict[builtins.str, typing.Any]]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__45df909985d7710dff82477cbda9b29a68333854adc8004b51ba1aabaeff27f7(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f31612203fdcab1b52d339cac32268ee89f6379fedefa36dc39673df9ad506ba(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d9ccd329250c5d627b83296492d071fba5a935d8047589977e049d83783200be(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__112a714bc828ea93a8ced59e1f71be5af3c5042f334b5e4671cba0072bb3a348(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cffed96ee07439c94a9f6a4c75ac70de6b6a89c108940a975e87e0505c68b96f(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    location: builtins.str,
+    size: jsii.Number,
+    id: typing.Optional[builtins.str] = None,
+    ip_consumers: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[IpblockIpConsumers, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    name: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[IpblockTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a4679ca26966553fb1eb04ed733d8c0cce22b6eba7eeeaf3add5691776ebf124(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    wraps_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__627ee3094f92b1723e9330c4a514e01f38d124701a196b46c1297ad94d5aedfd(
+    index: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__536658ce10d9cab682fcbc15e8214a73d21e55c621366baaf109df1752bf209f(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__90cc3bde2be2292aebe5a2b3b36b67eff20f4f24022e4f4a11313e48c90ae76c(
+    value: _cdktf_9a9027ec.IInterpolatingParent,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0a34510b9c903a5f13e3f8a65a9f83dcefbe722361f700964c9bbcfe766f14ee(
+    value: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2ea4e4de4cc0c7955d508c06686532e74d9d3dd58d790fc1f28ebf7454e6a21c(
+    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[IpblockIpConsumers]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f2aa45d5414decbe84662084667f5ca8ea96d38c953197cdaae44a19b21b565f(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    complex_object_index: jsii.Number,
+    complex_object_is_from_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__65ef6a9a6a740ca507f6cc45b92a675b904faba3df1455826ec1a1b5c7365239(
+    value: typing.Optional[typing.Union[IpblockIpConsumers, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__22a759e3956a9cf72d78cb091a9cc3cbb975e84f07c1e3f51a8d207fad590039(
+    *,
+    create: typing.Optional[builtins.str] = None,
+    default: typing.Optional[builtins.str] = None,
+    delete: typing.Optional[builtins.str] = None,
+    update: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bfce2652ce2f0711bc529eebe652dd41714a309cb2a512eedca66249da248d70(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dd0dca060497554a5cef3ff7900ceb4cc3ff86eba5698d2609a1c143de29f22b(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__233ea2d435904f5d7a238902fa542d3123c9400fc05cd22e2b3101fa151c93bb(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__210384728d28cf355d19dc15d192902f7b967acc0e6b822763437699a34a7e4b(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__df966f78b473703dd5191315a10b9b32b665248ff7bd7ae8b87fa8795b63b9ae(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__380bdb114d61ab3640416b0550a03c1263426c493502b62972471692001d0471(
+    value: typing.Optional[typing.Union[IpblockTimeouts, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
