@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class NatgatewayRule(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.natgatewayRule.NatgatewayRule",
 ):
@@ -30,7 +30,7 @@ class NatgatewayRule(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         datacenter_id: builtins.str,
@@ -40,17 +40,17 @@ class NatgatewayRule(
         source_subnet: builtins.str,
         id: typing.Optional[builtins.str] = None,
         protocol: typing.Optional[builtins.str] = None,
-        target_port_range: typing.Optional[typing.Union["NatgatewayRuleTargetPortRange", typing.Dict[str, typing.Any]]] = None,
+        target_port_range: typing.Optional[typing.Union["NatgatewayRuleTargetPortRange", typing.Dict[builtins.str, typing.Any]]] = None,
         target_subnet: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["NatgatewayRuleTimeouts", typing.Dict[str, typing.Any]]] = None,
+        timeouts: typing.Optional[typing.Union["NatgatewayRuleTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
         type: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/ionoscloud/r/natgateway_rule ionoscloud_natgateway_rule} Resource.
 
@@ -76,7 +76,7 @@ class NatgatewayRule(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NatgatewayRule.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__37340147fc7c65612a48485c9ebd3df85c0c664ed3d1f3ff657855e83dd90fbd)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = NatgatewayRuleConfig(
@@ -232,8 +232,8 @@ class NatgatewayRule(
     @jsii.member(jsii_name="timeoutsInput")
     def timeouts_input(
         self,
-    ) -> typing.Optional[typing.Union["NatgatewayRuleTimeouts", cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union["NatgatewayRuleTimeouts", cdktf.IResolvable]], jsii.get(self, "timeoutsInput"))
+    ) -> typing.Optional[typing.Union["NatgatewayRuleTimeouts", _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union["NatgatewayRuleTimeouts", _cdktf_9a9027ec.IResolvable]], jsii.get(self, "timeoutsInput"))
 
     @builtins.property
     @jsii.member(jsii_name="typeInput")
@@ -248,7 +248,7 @@ class NatgatewayRule(
     @datacenter_id.setter
     def datacenter_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NatgatewayRule, "datacenter_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__19f2dc006fbe02f6c91aa881c2653bfd08df7de9c668da4fc30a4f49a10f1768)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "datacenterId", value)
 
@@ -260,7 +260,7 @@ class NatgatewayRule(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NatgatewayRule, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__e42ab693da5d3739d3a990e0b1ecd308d8b47486d510b0d70db558775a4f4f93)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -272,7 +272,7 @@ class NatgatewayRule(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NatgatewayRule, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__37faa13354e93567748f652b69016eb2b1d82356ffd2b47b051e67d250e50314)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -284,7 +284,7 @@ class NatgatewayRule(
     @natgateway_id.setter
     def natgateway_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NatgatewayRule, "natgateway_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7b3c2ceafb746b1026c10f4e33cf9428493f6df57c7a66bc5d816ae75edad2c4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "natgatewayId", value)
 
@@ -296,7 +296,7 @@ class NatgatewayRule(
     @protocol.setter
     def protocol(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NatgatewayRule, "protocol").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__3474bb289e7ab9ca309ca6f1c2e698c0d4d3ab4ae7b5f05c795f8f8cf88f17dd)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "protocol", value)
 
@@ -308,7 +308,7 @@ class NatgatewayRule(
     @public_ip.setter
     def public_ip(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NatgatewayRule, "public_ip").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__aeedf858780b929ab42594a2be4e2f695b1d1c11cd271910e1aefcee3f5535db)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "publicIp", value)
 
@@ -320,7 +320,7 @@ class NatgatewayRule(
     @source_subnet.setter
     def source_subnet(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NatgatewayRule, "source_subnet").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__bc8634acc41f4151747eb9fc6b3aa59ff6883dd46e559045b0f6121756fa9017)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sourceSubnet", value)
 
@@ -332,7 +332,7 @@ class NatgatewayRule(
     @target_subnet.setter
     def target_subnet(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NatgatewayRule, "target_subnet").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d6be26afe710a40e09085c51ceff97ca752819e88f8c015b739b9f4bc0d540c5)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "targetSubnet", value)
 
@@ -344,14 +344,14 @@ class NatgatewayRule(
     @type.setter
     def type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NatgatewayRule, "type").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__3d0554fe619c4378814c22dd3dcc57e8830fa97a3c3e666d181d565b46b31a4d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "type", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-ionoscloud.natgatewayRule.NatgatewayRuleConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -373,17 +373,17 @@ class NatgatewayRule(
         "type": "type",
     },
 )
-class NatgatewayRuleConfig(cdktf.TerraformMetaArguments):
+class NatgatewayRuleConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         datacenter_id: builtins.str,
         name: builtins.str,
         natgateway_id: builtins.str,
@@ -391,9 +391,9 @@ class NatgatewayRuleConfig(cdktf.TerraformMetaArguments):
         source_subnet: builtins.str,
         id: typing.Optional[builtins.str] = None,
         protocol: typing.Optional[builtins.str] = None,
-        target_port_range: typing.Optional[typing.Union["NatgatewayRuleTargetPortRange", typing.Dict[str, typing.Any]]] = None,
+        target_port_range: typing.Optional[typing.Union["NatgatewayRuleTargetPortRange", typing.Dict[builtins.str, typing.Any]]] = None,
         target_subnet: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["NatgatewayRuleTimeouts", typing.Dict[str, typing.Any]]] = None,
+        timeouts: typing.Optional[typing.Union["NatgatewayRuleTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
         type: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -417,13 +417,13 @@ class NatgatewayRuleConfig(cdktf.TerraformMetaArguments):
         :param type: Type of the NAT gateway rule. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/r/natgateway_rule#type NatgatewayRule#type}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(target_port_range, dict):
             target_port_range = NatgatewayRuleTargetPortRange(**target_port_range)
         if isinstance(timeouts, dict):
             timeouts = NatgatewayRuleTimeouts(**timeouts)
         if __debug__:
-            type_hints = typing.get_type_hints(NatgatewayRuleConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__0a373f291e00cc454fd59697e5e0fb9c8d17dd6cb2020113aea626989c74e52e)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -442,7 +442,7 @@ class NatgatewayRuleConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument target_subnet", value=target_subnet, expected_type=type_hints["target_subnet"])
             check_type(argname="argument timeouts", value=timeouts, expected_type=type_hints["timeouts"])
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "datacenter_id": datacenter_id,
             "name": name,
             "natgateway_id": natgateway_id,
@@ -479,12 +479,12 @@ class NatgatewayRuleConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -495,46 +495,48 @@ class NatgatewayRuleConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def datacenter_id(self) -> builtins.str:
@@ -672,10 +674,10 @@ class NatgatewayRuleTargetPortRange:
         :param start: Target port range start associated with the NAT gateway rule. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/r/natgateway_rule#start NatgatewayRule#start}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NatgatewayRuleTargetPortRange.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__92139c067f0a574c161e8e908b2dfda1063e1ea96b99a2b12ca9c2ecd598ca6e)
             check_type(argname="argument end", value=end, expected_type=type_hints["end"])
             check_type(argname="argument start", value=start, expected_type=type_hints["start"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if end is not None:
             self._values["end"] = end
         if start is not None:
@@ -712,13 +714,13 @@ class NatgatewayRuleTargetPortRange:
 
 
 class NatgatewayRuleTargetPortRangeOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.natgatewayRule.NatgatewayRuleTargetPortRangeOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -726,7 +728,7 @@ class NatgatewayRuleTargetPortRangeOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NatgatewayRuleTargetPortRangeOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__2a8aee052d9e3e41ca25da20f7dd35b40987d1333bf7f5d7b6294c54df2d7fb5)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -757,7 +759,7 @@ class NatgatewayRuleTargetPortRangeOutputReference(
     @end.setter
     def end(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NatgatewayRuleTargetPortRangeOutputReference, "end").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__f0e3076416a235f0590af5595f857b4fbdd28df200115f707a62d6946f54bc2a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "end", value)
 
@@ -769,7 +771,7 @@ class NatgatewayRuleTargetPortRangeOutputReference(
     @start.setter
     def start(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NatgatewayRuleTargetPortRangeOutputReference, "start").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__57ef0e1b58d2852128ad115392473d58bbed7afa1d6235f87ebdbff199db0824)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "start", value)
 
@@ -784,7 +786,7 @@ class NatgatewayRuleTargetPortRangeOutputReference(
         value: typing.Optional[NatgatewayRuleTargetPortRange],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NatgatewayRuleTargetPortRangeOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7d0dedae6dd570b9c49a9992f4f44b8353d3ce758f45ba98ab4f4bcfe0d4c5e5)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -815,12 +817,12 @@ class NatgatewayRuleTimeouts:
         :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/r/natgateway_rule#update NatgatewayRule#update}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NatgatewayRuleTimeouts.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__7ea03bea3c638dfc0920f6ff24ecd5d137b33eb37111f76cdc4fd4773a9fe472)
             check_type(argname="argument create", value=create, expected_type=type_hints["create"])
             check_type(argname="argument default", value=default, expected_type=type_hints["default"])
             check_type(argname="argument delete", value=delete, expected_type=type_hints["delete"])
             check_type(argname="argument update", value=update, expected_type=type_hints["update"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if create is not None:
             self._values["create"] = create
         if default is not None:
@@ -867,13 +869,13 @@ class NatgatewayRuleTimeouts:
 
 
 class NatgatewayRuleTimeoutsOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.natgatewayRule.NatgatewayRuleTimeoutsOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -881,7 +883,7 @@ class NatgatewayRuleTimeoutsOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NatgatewayRuleTimeoutsOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__063f438cb1d54323437434d511f8dff2dbba77c800d58245689b143c90f7c41c)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -930,7 +932,7 @@ class NatgatewayRuleTimeoutsOutputReference(
     @create.setter
     def create(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NatgatewayRuleTimeoutsOutputReference, "create").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__8c020378ddef4776fff1342b41bd5a4f51fdd00e3ab55d5d4af1541f9f0f4f45)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "create", value)
 
@@ -942,7 +944,7 @@ class NatgatewayRuleTimeoutsOutputReference(
     @default.setter
     def default(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NatgatewayRuleTimeoutsOutputReference, "default").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__34ebf5e16239193adfa73ff9617de82c7fdf877886773fad1bcb54937ddd7845)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "default", value)
 
@@ -954,7 +956,7 @@ class NatgatewayRuleTimeoutsOutputReference(
     @delete.setter
     def delete(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NatgatewayRuleTimeoutsOutputReference, "delete").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__04487bffdf4bda45f95bd5cb7225592e452b0a1637b9deacf1b7df4de795009c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "delete", value)
 
@@ -966,7 +968,7 @@ class NatgatewayRuleTimeoutsOutputReference(
     @update.setter
     def update(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NatgatewayRuleTimeoutsOutputReference, "update").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__b3743d1f7ed81eae97b6600590b79b0b87fd6f2be612b0c292003e65cf2831bb)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "update", value)
 
@@ -974,16 +976,16 @@ class NatgatewayRuleTimeoutsOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[NatgatewayRuleTimeouts, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[NatgatewayRuleTimeouts, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[NatgatewayRuleTimeouts, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[NatgatewayRuleTimeouts, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[NatgatewayRuleTimeouts, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[NatgatewayRuleTimeouts, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NatgatewayRuleTimeoutsOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__f1b0beeb53c40a1a42549aac0f6cdc92d3a0e8158a311a10dc6a13ab261cc780)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -998,3 +1000,187 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__37340147fc7c65612a48485c9ebd3df85c0c664ed3d1f3ff657855e83dd90fbd(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    datacenter_id: builtins.str,
+    name: builtins.str,
+    natgateway_id: builtins.str,
+    public_ip: builtins.str,
+    source_subnet: builtins.str,
+    id: typing.Optional[builtins.str] = None,
+    protocol: typing.Optional[builtins.str] = None,
+    target_port_range: typing.Optional[typing.Union[NatgatewayRuleTargetPortRange, typing.Dict[builtins.str, typing.Any]]] = None,
+    target_subnet: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[NatgatewayRuleTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+    type: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__19f2dc006fbe02f6c91aa881c2653bfd08df7de9c668da4fc30a4f49a10f1768(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e42ab693da5d3739d3a990e0b1ecd308d8b47486d510b0d70db558775a4f4f93(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__37faa13354e93567748f652b69016eb2b1d82356ffd2b47b051e67d250e50314(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7b3c2ceafb746b1026c10f4e33cf9428493f6df57c7a66bc5d816ae75edad2c4(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3474bb289e7ab9ca309ca6f1c2e698c0d4d3ab4ae7b5f05c795f8f8cf88f17dd(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__aeedf858780b929ab42594a2be4e2f695b1d1c11cd271910e1aefcee3f5535db(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bc8634acc41f4151747eb9fc6b3aa59ff6883dd46e559045b0f6121756fa9017(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d6be26afe710a40e09085c51ceff97ca752819e88f8c015b739b9f4bc0d540c5(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3d0554fe619c4378814c22dd3dcc57e8830fa97a3c3e666d181d565b46b31a4d(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0a373f291e00cc454fd59697e5e0fb9c8d17dd6cb2020113aea626989c74e52e(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    datacenter_id: builtins.str,
+    name: builtins.str,
+    natgateway_id: builtins.str,
+    public_ip: builtins.str,
+    source_subnet: builtins.str,
+    id: typing.Optional[builtins.str] = None,
+    protocol: typing.Optional[builtins.str] = None,
+    target_port_range: typing.Optional[typing.Union[NatgatewayRuleTargetPortRange, typing.Dict[builtins.str, typing.Any]]] = None,
+    target_subnet: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[NatgatewayRuleTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+    type: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__92139c067f0a574c161e8e908b2dfda1063e1ea96b99a2b12ca9c2ecd598ca6e(
+    *,
+    end: typing.Optional[jsii.Number] = None,
+    start: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2a8aee052d9e3e41ca25da20f7dd35b40987d1333bf7f5d7b6294c54df2d7fb5(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f0e3076416a235f0590af5595f857b4fbdd28df200115f707a62d6946f54bc2a(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__57ef0e1b58d2852128ad115392473d58bbed7afa1d6235f87ebdbff199db0824(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7d0dedae6dd570b9c49a9992f4f44b8353d3ce758f45ba98ab4f4bcfe0d4c5e5(
+    value: typing.Optional[NatgatewayRuleTargetPortRange],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7ea03bea3c638dfc0920f6ff24ecd5d137b33eb37111f76cdc4fd4773a9fe472(
+    *,
+    create: typing.Optional[builtins.str] = None,
+    default: typing.Optional[builtins.str] = None,
+    delete: typing.Optional[builtins.str] = None,
+    update: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__063f438cb1d54323437434d511f8dff2dbba77c800d58245689b143c90f7c41c(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8c020378ddef4776fff1342b41bd5a4f51fdd00e3ab55d5d4af1541f9f0f4f45(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__34ebf5e16239193adfa73ff9617de82c7fdf877886773fad1bcb54937ddd7845(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__04487bffdf4bda45f95bd5cb7225592e452b0a1637b9deacf1b7df4de795009c(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b3743d1f7ed81eae97b6600590b79b0b87fd6f2be612b0c292003e65cf2831bb(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f1b0beeb53c40a1a42549aac0f6cdc92d3a0e8158a311a10dc6a13ab261cc780(
+    value: typing.Optional[typing.Union[NatgatewayRuleTimeouts, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
