@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class Share(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.share.Share",
 ):
@@ -30,22 +30,22 @@ class Share(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         group_id: builtins.str,
         resource_id: builtins.str,
-        edit_privilege: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        edit_privilege: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
-        share_privilege: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-        timeouts: typing.Optional[typing.Union["ShareTimeouts", typing.Dict[str, typing.Any]]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        share_privilege: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+        timeouts: typing.Optional[typing.Union["ShareTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/ionoscloud/r/share ionoscloud_share} Resource.
 
@@ -66,7 +66,7 @@ class Share(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Share.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__337f37a1fda3411718a295fa4f6157f5b46c53885e565749eefc41d479ba7c37)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = ShareConfig(
@@ -142,8 +142,8 @@ class Share(
     @jsii.member(jsii_name="editPrivilegeInput")
     def edit_privilege_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "editPrivilegeInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "editPrivilegeInput"))
 
     @builtins.property
     @jsii.member(jsii_name="groupIdInput")
@@ -164,28 +164,30 @@ class Share(
     @jsii.member(jsii_name="sharePrivilegeInput")
     def share_privilege_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "sharePrivilegeInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "sharePrivilegeInput"))
 
     @builtins.property
     @jsii.member(jsii_name="timeoutsInput")
     def timeouts_input(
         self,
-    ) -> typing.Optional[typing.Union["ShareTimeouts", cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union["ShareTimeouts", cdktf.IResolvable]], jsii.get(self, "timeoutsInput"))
+    ) -> typing.Optional[typing.Union["ShareTimeouts", _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union["ShareTimeouts", _cdktf_9a9027ec.IResolvable]], jsii.get(self, "timeoutsInput"))
 
     @builtins.property
     @jsii.member(jsii_name="editPrivilege")
-    def edit_privilege(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "editPrivilege"))
+    def edit_privilege(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "editPrivilege"))
 
     @edit_privilege.setter
     def edit_privilege(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Share, "edit_privilege").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__09c1234930be7fcb149decb94a78f65c1f11522c366d28bc91a32ecffa5b2fe4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "editPrivilege", value)
 
@@ -197,7 +199,7 @@ class Share(
     @group_id.setter
     def group_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Share, "group_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__daa08efc4b97826535c56ffe342486b4f68a5ee2f4793ab8fe33f44c98e3c9ee)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "groupId", value)
 
@@ -209,7 +211,7 @@ class Share(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Share, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__c1298e928664c35ff1e380d5be177ef8b1529bbaec8a7889766aa2160608a95c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -221,29 +223,31 @@ class Share(
     @resource_id.setter
     def resource_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Share, "resource_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__c1748a80970a32f10df8eaffaab4c35dd4ea04affb31d5388dbf3c9bc50fb845)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resourceId", value)
 
     @builtins.property
     @jsii.member(jsii_name="sharePrivilege")
-    def share_privilege(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "sharePrivilege"))
+    def share_privilege(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "sharePrivilege"))
 
     @share_privilege.setter
     def share_privilege(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Share, "share_privilege").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7dc477553d0b9033e93ddb520954f6ba596c43764f71a8e7130711de22ad95c1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sharePrivilege", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-ionoscloud.share.ShareConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -260,23 +264,23 @@ class Share(
         "timeouts": "timeouts",
     },
 )
-class ShareConfig(cdktf.TerraformMetaArguments):
+class ShareConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         group_id: builtins.str,
         resource_id: builtins.str,
-        edit_privilege: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        edit_privilege: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
-        share_privilege: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-        timeouts: typing.Optional[typing.Union["ShareTimeouts", typing.Dict[str, typing.Any]]] = None,
+        share_privilege: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+        timeouts: typing.Optional[typing.Union["ShareTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param connection: 
@@ -294,11 +298,11 @@ class ShareConfig(cdktf.TerraformMetaArguments):
         :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/r/share#timeouts Share#timeouts}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(timeouts, dict):
             timeouts = ShareTimeouts(**timeouts)
         if __debug__:
-            type_hints = typing.get_type_hints(ShareConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__a13bdcf18939d138180b13d42a32c14f7ccd4a6334e3fa703e31ad23ce6352ea)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -312,7 +316,7 @@ class ShareConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument share_privilege", value=share_privilege, expected_type=type_hints["share_privilege"])
             check_type(argname="argument timeouts", value=timeouts, expected_type=type_hints["timeouts"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "group_id": group_id,
             "resource_id": resource_id,
         }
@@ -342,12 +346,12 @@ class ShareConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -358,46 +362,48 @@ class ShareConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def group_id(self) -> builtins.str:
@@ -416,10 +422,10 @@ class ShareConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def edit_privilege(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/r/share#edit_privilege Share#edit_privilege}.'''
         result = self._values.get("edit_privilege")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
@@ -434,10 +440,10 @@ class ShareConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def share_privilege(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/r/share#share_privilege Share#share_privilege}.'''
         result = self._values.get("share_privilege")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def timeouts(self) -> typing.Optional["ShareTimeouts"]:
@@ -486,12 +492,12 @@ class ShareTimeouts:
         :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/r/share#update Share#update}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ShareTimeouts.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__41f18cdb5d50c99e993936b4caebadf759b0d2053612e235a01e992e89e37829)
             check_type(argname="argument create", value=create, expected_type=type_hints["create"])
             check_type(argname="argument default", value=default, expected_type=type_hints["default"])
             check_type(argname="argument delete", value=delete, expected_type=type_hints["delete"])
             check_type(argname="argument update", value=update, expected_type=type_hints["update"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if create is not None:
             self._values["create"] = create
         if default is not None:
@@ -538,13 +544,13 @@ class ShareTimeouts:
 
 
 class ShareTimeoutsOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.share.ShareTimeoutsOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -552,7 +558,7 @@ class ShareTimeoutsOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ShareTimeoutsOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__12802759c07e7cd7bc65e931650672f7ecb56a2db3751bad0d65b1c49e27aced)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -601,7 +607,7 @@ class ShareTimeoutsOutputReference(
     @create.setter
     def create(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ShareTimeoutsOutputReference, "create").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__1cf61c716366a6325a898ee3c18f1ccc3f0bbd8dba57b98a95b4f42f2b8ec6d0)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "create", value)
 
@@ -613,7 +619,7 @@ class ShareTimeoutsOutputReference(
     @default.setter
     def default(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ShareTimeoutsOutputReference, "default").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__c4fb89f58274f8a25bc542d47331261e5c17078b01829d4452663d2bb9b12b8d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "default", value)
 
@@ -625,7 +631,7 @@ class ShareTimeoutsOutputReference(
     @delete.setter
     def delete(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ShareTimeoutsOutputReference, "delete").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__f50366ecd698c5e39f8775d87e5857443ea24f936df232dafeac253fc4e19953)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "delete", value)
 
@@ -637,7 +643,7 @@ class ShareTimeoutsOutputReference(
     @update.setter
     def update(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ShareTimeoutsOutputReference, "update").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__141902af3f067fadf6b45fe4416010b452a3e1fd2064be1b41aa3d20219b22bd)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "update", value)
 
@@ -645,16 +651,16 @@ class ShareTimeoutsOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[ShareTimeouts, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[ShareTimeouts, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[ShareTimeouts, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[ShareTimeouts, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[ShareTimeouts, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[ShareTimeouts, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ShareTimeoutsOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5ab3229f3d98eae9ab42cfcb958572dcdae4e586cad60fc4d68bd7c8850231e6)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -667,3 +673,120 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__337f37a1fda3411718a295fa4f6157f5b46c53885e565749eefc41d479ba7c37(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    group_id: builtins.str,
+    resource_id: builtins.str,
+    edit_privilege: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+    share_privilege: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    timeouts: typing.Optional[typing.Union[ShareTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__09c1234930be7fcb149decb94a78f65c1f11522c366d28bc91a32ecffa5b2fe4(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__daa08efc4b97826535c56ffe342486b4f68a5ee2f4793ab8fe33f44c98e3c9ee(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c1298e928664c35ff1e380d5be177ef8b1529bbaec8a7889766aa2160608a95c(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c1748a80970a32f10df8eaffaab4c35dd4ea04affb31d5388dbf3c9bc50fb845(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7dc477553d0b9033e93ddb520954f6ba596c43764f71a8e7130711de22ad95c1(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a13bdcf18939d138180b13d42a32c14f7ccd4a6334e3fa703e31ad23ce6352ea(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    group_id: builtins.str,
+    resource_id: builtins.str,
+    edit_privilege: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+    share_privilege: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    timeouts: typing.Optional[typing.Union[ShareTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__41f18cdb5d50c99e993936b4caebadf759b0d2053612e235a01e992e89e37829(
+    *,
+    create: typing.Optional[builtins.str] = None,
+    default: typing.Optional[builtins.str] = None,
+    delete: typing.Optional[builtins.str] = None,
+    update: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__12802759c07e7cd7bc65e931650672f7ecb56a2db3751bad0d65b1c49e27aced(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1cf61c716366a6325a898ee3c18f1ccc3f0bbd8dba57b98a95b4f42f2b8ec6d0(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c4fb89f58274f8a25bc542d47331261e5c17078b01829d4452663d2bb9b12b8d(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f50366ecd698c5e39f8775d87e5857443ea24f936df232dafeac253fc4e19953(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__141902af3f067fadf6b45fe4416010b452a3e1fd2064be1b41aa3d20219b22bd(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5ab3229f3d98eae9ab42cfcb958572dcdae4e586cad60fc4d68bd7c8850231e6(
+    value: typing.Optional[typing.Union[ShareTimeouts, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
