@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class Snapshot(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.snapshot.Snapshot",
 ):
@@ -30,21 +30,21 @@ class Snapshot(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         datacenter_id: builtins.str,
         name: builtins.str,
         volume_id: builtins.str,
         id: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["SnapshotTimeouts", typing.Dict[str, typing.Any]]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        timeouts: typing.Optional[typing.Union["SnapshotTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/ionoscloud/r/snapshot ionoscloud_snapshot} Resource.
 
@@ -64,7 +64,7 @@ class Snapshot(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Snapshot.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__4ecf003295fd8d2ee3d343db2d4e7cc50a5741d18911dde981eba9029a7d10b4)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = SnapshotConfig(
@@ -124,13 +124,13 @@ class Snapshot(
 
     @builtins.property
     @jsii.member(jsii_name="cpuHotPlug")
-    def cpu_hot_plug(self) -> cdktf.IResolvable:
-        return typing.cast(cdktf.IResolvable, jsii.get(self, "cpuHotPlug"))
+    def cpu_hot_plug(self) -> _cdktf_9a9027ec.IResolvable:
+        return typing.cast(_cdktf_9a9027ec.IResolvable, jsii.get(self, "cpuHotPlug"))
 
     @builtins.property
     @jsii.member(jsii_name="cpuHotUnplug")
-    def cpu_hot_unplug(self) -> cdktf.IResolvable:
-        return typing.cast(cdktf.IResolvable, jsii.get(self, "cpuHotUnplug"))
+    def cpu_hot_unplug(self) -> _cdktf_9a9027ec.IResolvable:
+        return typing.cast(_cdktf_9a9027ec.IResolvable, jsii.get(self, "cpuHotUnplug"))
 
     @builtins.property
     @jsii.member(jsii_name="description")
@@ -139,23 +139,23 @@ class Snapshot(
 
     @builtins.property
     @jsii.member(jsii_name="discScsiHotPlug")
-    def disc_scsi_hot_plug(self) -> cdktf.IResolvable:
-        return typing.cast(cdktf.IResolvable, jsii.get(self, "discScsiHotPlug"))
+    def disc_scsi_hot_plug(self) -> _cdktf_9a9027ec.IResolvable:
+        return typing.cast(_cdktf_9a9027ec.IResolvable, jsii.get(self, "discScsiHotPlug"))
 
     @builtins.property
     @jsii.member(jsii_name="discScsiHotUnplug")
-    def disc_scsi_hot_unplug(self) -> cdktf.IResolvable:
-        return typing.cast(cdktf.IResolvable, jsii.get(self, "discScsiHotUnplug"))
+    def disc_scsi_hot_unplug(self) -> _cdktf_9a9027ec.IResolvable:
+        return typing.cast(_cdktf_9a9027ec.IResolvable, jsii.get(self, "discScsiHotUnplug"))
 
     @builtins.property
     @jsii.member(jsii_name="discVirtioHotPlug")
-    def disc_virtio_hot_plug(self) -> cdktf.IResolvable:
-        return typing.cast(cdktf.IResolvable, jsii.get(self, "discVirtioHotPlug"))
+    def disc_virtio_hot_plug(self) -> _cdktf_9a9027ec.IResolvable:
+        return typing.cast(_cdktf_9a9027ec.IResolvable, jsii.get(self, "discVirtioHotPlug"))
 
     @builtins.property
     @jsii.member(jsii_name="discVirtioHotUnplug")
-    def disc_virtio_hot_unplug(self) -> cdktf.IResolvable:
-        return typing.cast(cdktf.IResolvable, jsii.get(self, "discVirtioHotUnplug"))
+    def disc_virtio_hot_unplug(self) -> _cdktf_9a9027ec.IResolvable:
+        return typing.cast(_cdktf_9a9027ec.IResolvable, jsii.get(self, "discVirtioHotUnplug"))
 
     @builtins.property
     @jsii.member(jsii_name="licenceType")
@@ -169,28 +169,28 @@ class Snapshot(
 
     @builtins.property
     @jsii.member(jsii_name="nicHotPlug")
-    def nic_hot_plug(self) -> cdktf.IResolvable:
-        return typing.cast(cdktf.IResolvable, jsii.get(self, "nicHotPlug"))
+    def nic_hot_plug(self) -> _cdktf_9a9027ec.IResolvable:
+        return typing.cast(_cdktf_9a9027ec.IResolvable, jsii.get(self, "nicHotPlug"))
 
     @builtins.property
     @jsii.member(jsii_name="nicHotUnplug")
-    def nic_hot_unplug(self) -> cdktf.IResolvable:
-        return typing.cast(cdktf.IResolvable, jsii.get(self, "nicHotUnplug"))
+    def nic_hot_unplug(self) -> _cdktf_9a9027ec.IResolvable:
+        return typing.cast(_cdktf_9a9027ec.IResolvable, jsii.get(self, "nicHotUnplug"))
 
     @builtins.property
     @jsii.member(jsii_name="ramHotPlug")
-    def ram_hot_plug(self) -> cdktf.IResolvable:
-        return typing.cast(cdktf.IResolvable, jsii.get(self, "ramHotPlug"))
+    def ram_hot_plug(self) -> _cdktf_9a9027ec.IResolvable:
+        return typing.cast(_cdktf_9a9027ec.IResolvable, jsii.get(self, "ramHotPlug"))
 
     @builtins.property
     @jsii.member(jsii_name="ramHotUnplug")
-    def ram_hot_unplug(self) -> cdktf.IResolvable:
-        return typing.cast(cdktf.IResolvable, jsii.get(self, "ramHotUnplug"))
+    def ram_hot_unplug(self) -> _cdktf_9a9027ec.IResolvable:
+        return typing.cast(_cdktf_9a9027ec.IResolvable, jsii.get(self, "ramHotUnplug"))
 
     @builtins.property
     @jsii.member(jsii_name="secAuthProtection")
-    def sec_auth_protection(self) -> cdktf.IResolvable:
-        return typing.cast(cdktf.IResolvable, jsii.get(self, "secAuthProtection"))
+    def sec_auth_protection(self) -> _cdktf_9a9027ec.IResolvable:
+        return typing.cast(_cdktf_9a9027ec.IResolvable, jsii.get(self, "secAuthProtection"))
 
     @builtins.property
     @jsii.member(jsii_name="size")
@@ -221,8 +221,8 @@ class Snapshot(
     @jsii.member(jsii_name="timeoutsInput")
     def timeouts_input(
         self,
-    ) -> typing.Optional[typing.Union["SnapshotTimeouts", cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union["SnapshotTimeouts", cdktf.IResolvable]], jsii.get(self, "timeoutsInput"))
+    ) -> typing.Optional[typing.Union["SnapshotTimeouts", _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union["SnapshotTimeouts", _cdktf_9a9027ec.IResolvable]], jsii.get(self, "timeoutsInput"))
 
     @builtins.property
     @jsii.member(jsii_name="volumeIdInput")
@@ -237,7 +237,7 @@ class Snapshot(
     @datacenter_id.setter
     def datacenter_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Snapshot, "datacenter_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__9aeb75bf40e365671d16a4fc77a9376d2e9576d0be51186df6c4ac51cd85ffee)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "datacenterId", value)
 
@@ -249,7 +249,7 @@ class Snapshot(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Snapshot, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__0425bf200b8c084b1b178184fbbcbaa8b93f252f43b47bcf7dff80b726989c9a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -261,7 +261,7 @@ class Snapshot(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Snapshot, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__851914fbc2ec4330fd91c07004166fd626050688bbaa1d415a7bb119dd1dcd0d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -273,14 +273,14 @@ class Snapshot(
     @volume_id.setter
     def volume_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Snapshot, "volume_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__97122b6a5b2e8b35ff9e889d4ed0ccc203ce602bd06bdd04a191716ade9e8f63)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "volumeId", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-ionoscloud.snapshot.SnapshotConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -296,22 +296,22 @@ class Snapshot(
         "timeouts": "timeouts",
     },
 )
-class SnapshotConfig(cdktf.TerraformMetaArguments):
+class SnapshotConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         datacenter_id: builtins.str,
         name: builtins.str,
         volume_id: builtins.str,
         id: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["SnapshotTimeouts", typing.Dict[str, typing.Any]]] = None,
+        timeouts: typing.Optional[typing.Union["SnapshotTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param connection: 
@@ -328,11 +328,11 @@ class SnapshotConfig(cdktf.TerraformMetaArguments):
         :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/r/snapshot#timeouts Snapshot#timeouts}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(timeouts, dict):
             timeouts = SnapshotTimeouts(**timeouts)
         if __debug__:
-            type_hints = typing.get_type_hints(SnapshotConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__def1dea92956da1382458cbf8f6d25d0eb1d458ec809fa9f5323afd0cc6a5aaf)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -345,7 +345,7 @@ class SnapshotConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument volume_id", value=volume_id, expected_type=type_hints["volume_id"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument timeouts", value=timeouts, expected_type=type_hints["timeouts"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "datacenter_id": datacenter_id,
             "name": name,
             "volume_id": volume_id,
@@ -372,12 +372,12 @@ class SnapshotConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -388,46 +388,48 @@ class SnapshotConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def datacenter_id(self) -> builtins.str:
@@ -510,12 +512,12 @@ class SnapshotTimeouts:
         :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ionoscloud/r/snapshot#update Snapshot#update}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SnapshotTimeouts.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__b65afe72410a5f9f4e51c7bcf65572b9c5e422fd209afa8c65f1e8892d4c43c6)
             check_type(argname="argument create", value=create, expected_type=type_hints["create"])
             check_type(argname="argument default", value=default, expected_type=type_hints["default"])
             check_type(argname="argument delete", value=delete, expected_type=type_hints["delete"])
             check_type(argname="argument update", value=update, expected_type=type_hints["update"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if create is not None:
             self._values["create"] = create
         if default is not None:
@@ -562,13 +564,13 @@ class SnapshotTimeouts:
 
 
 class SnapshotTimeoutsOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-ionoscloud.snapshot.SnapshotTimeoutsOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -576,7 +578,7 @@ class SnapshotTimeoutsOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SnapshotTimeoutsOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__0511e2fbaea91551b5879f010cca00488ff6388d7663c1f18610e918710421e9)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -625,7 +627,7 @@ class SnapshotTimeoutsOutputReference(
     @create.setter
     def create(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(SnapshotTimeoutsOutputReference, "create").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__cac07f03627ad2dbef7829e561364584ce796f9ecf9dc2d981fe9dfd5319cbdc)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "create", value)
 
@@ -637,7 +639,7 @@ class SnapshotTimeoutsOutputReference(
     @default.setter
     def default(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(SnapshotTimeoutsOutputReference, "default").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__ad9dc4202a68a8745cb8330daa9525cea747f360dcfa083abe2b6c7803a73d23)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "default", value)
 
@@ -649,7 +651,7 @@ class SnapshotTimeoutsOutputReference(
     @delete.setter
     def delete(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(SnapshotTimeoutsOutputReference, "delete").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__a986de6c86ef0295c1dc370f7d3f5894e068923346463a9ab740b52515c5eb5e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "delete", value)
 
@@ -661,7 +663,7 @@ class SnapshotTimeoutsOutputReference(
     @update.setter
     def update(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(SnapshotTimeoutsOutputReference, "update").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__961489176010e41c5eccfa0cee3cfa8a5589baae299f6ba810b48273d96d2b0f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "update", value)
 
@@ -669,16 +671,16 @@ class SnapshotTimeoutsOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[SnapshotTimeouts, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[SnapshotTimeouts, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[SnapshotTimeouts, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[SnapshotTimeouts, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[SnapshotTimeouts, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[SnapshotTimeouts, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(SnapshotTimeoutsOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__778c5de9e767ff2667630ce0d05a14ed16bed347b121a96c92e17bf77af0568e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -691,3 +693,112 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__4ecf003295fd8d2ee3d343db2d4e7cc50a5741d18911dde981eba9029a7d10b4(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    datacenter_id: builtins.str,
+    name: builtins.str,
+    volume_id: builtins.str,
+    id: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[SnapshotTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9aeb75bf40e365671d16a4fc77a9376d2e9576d0be51186df6c4ac51cd85ffee(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0425bf200b8c084b1b178184fbbcbaa8b93f252f43b47bcf7dff80b726989c9a(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__851914fbc2ec4330fd91c07004166fd626050688bbaa1d415a7bb119dd1dcd0d(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__97122b6a5b2e8b35ff9e889d4ed0ccc203ce602bd06bdd04a191716ade9e8f63(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__def1dea92956da1382458cbf8f6d25d0eb1d458ec809fa9f5323afd0cc6a5aaf(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    datacenter_id: builtins.str,
+    name: builtins.str,
+    volume_id: builtins.str,
+    id: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[SnapshotTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b65afe72410a5f9f4e51c7bcf65572b9c5e422fd209afa8c65f1e8892d4c43c6(
+    *,
+    create: typing.Optional[builtins.str] = None,
+    default: typing.Optional[builtins.str] = None,
+    delete: typing.Optional[builtins.str] = None,
+    update: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0511e2fbaea91551b5879f010cca00488ff6388d7663c1f18610e918710421e9(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cac07f03627ad2dbef7829e561364584ce796f9ecf9dc2d981fe9dfd5319cbdc(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ad9dc4202a68a8745cb8330daa9525cea747f360dcfa083abe2b6c7803a73d23(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a986de6c86ef0295c1dc370f7d3f5894e068923346463a9ab740b52515c5eb5e(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__961489176010e41c5eccfa0cee3cfa8a5589baae299f6ba810b48273d96d2b0f(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__778c5de9e767ff2667630ce0d05a14ed16bed347b121a96c92e17bf77af0568e(
+    value: typing.Optional[typing.Union[SnapshotTimeouts, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
